/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtDataVisualizationAPI_H
#define _QtDataVisualizationAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QtDataVisualization__QItemModelSurfaceDataProxy__MultiMatchBehavior 0
#define sipName_QtDataVisualization__QItemModelSurfaceDataProxy__MultiMatchBehavior &sipStrings_QtDataVisualization[0]
#define sipNameNr_QtDataVisualization__QItemModelBarDataProxy__MultiMatchBehavior 68
#define sipName_QtDataVisualization__QItemModelBarDataProxy__MultiMatchBehavior &sipStrings_QtDataVisualization[68]
#define sipNameNr_QtDataVisualization__QAbstract3DGraph__OptimizationHints 132
#define sipName_QtDataVisualization__QAbstract3DGraph__OptimizationHints &sipStrings_QtDataVisualization[132]
#define sipNameNr_QtDataVisualization__QAbstract3DGraph__OptimizationHint 189
#define sipName_QtDataVisualization__QAbstract3DGraph__OptimizationHint &sipStrings_QtDataVisualization[189]
#define sipNameNr_QtDataVisualization__QAbstract3DInputHandler__InputView 245
#define sipName_QtDataVisualization__QAbstract3DInputHandler__InputView &sipStrings_QtDataVisualization[245]
#define sipNameNr_301 301
#define sipName_301 &sipStrings_QtDataVisualization[301]
#define sipNameNr_QtDataVisualization__QAbstract3DAxis__AxisOrientation 356
#define sipName_QtDataVisualization__QAbstract3DAxis__AxisOrientation &sipStrings_QtDataVisualization[356]
#define sipNameNr_QtDataVisualization__QAbstract3DGraph__SelectionFlags 410
#define sipName_QtDataVisualization__QAbstract3DGraph__SelectionFlags &sipStrings_QtDataVisualization[410]
#define sipNameNr_464 464
#define sipName_464 &sipStrings_QtDataVisualization[464]
#define sipNameNr_QtDataVisualization__QAbstract3DGraph__SelectionFlag 517
#define sipName_QtDataVisualization__QAbstract3DGraph__SelectionFlag &sipStrings_QtDataVisualization[517]
#define sipNameNr_QtDataVisualization__QAbstract3DGraph__ShadowQuality 570
#define sipName_QtDataVisualization__QAbstract3DGraph__ShadowQuality &sipStrings_QtDataVisualization[570]
#define sipNameNr_623 623
#define sipName_623 &sipStrings_QtDataVisualization[623]
#define sipNameNr_QtDataVisualization__QAbstract3DGraph__ElementType 674
#define sipName_QtDataVisualization__QAbstract3DGraph__ElementType &sipStrings_QtDataVisualization[674]
#define sipNameNr_QtDataVisualization__QAbstract3DSeries__SeriesType 725
#define sipName_QtDataVisualization__QAbstract3DSeries__SeriesType &sipStrings_QtDataVisualization[725]
#define sipNameNr_QtDataVisualization__QAbstractDataProxy__DataType 776
#define sipName_QtDataVisualization__QAbstractDataProxy__DataType &sipStrings_QtDataVisualization[776]
#define sipNameNr_QtDataVisualization__QSurface3DSeries__DrawFlags 826
#define sipName_QtDataVisualization__QSurface3DSeries__DrawFlags &sipStrings_QtDataVisualization[826]
#define sipNameNr_QtDataVisualization__QHeightMapSurfaceDataProxy 875
#define sipName_QtDataVisualization__QHeightMapSurfaceDataProxy &sipStrings_QtDataVisualization[875]
#define sipNameNr_QtDataVisualization__QItemModelScatterDataProxy 923
#define sipName_QtDataVisualization__QItemModelScatterDataProxy &sipStrings_QtDataVisualization[923]
#define sipNameNr_QtDataVisualization__QItemModelSurfaceDataProxy 971
#define sipName_QtDataVisualization__QItemModelSurfaceDataProxy &sipStrings_QtDataVisualization[971]
#define sipNameNr_QtDataVisualization__QSurface3DSeries__DrawFlag 1019
#define sipName_QtDataVisualization__QSurface3DSeries__DrawFlag &sipStrings_QtDataVisualization[1019]
#define sipNameNr_1067 1067
#define sipName_1067 &sipStrings_QtDataVisualization[1067]
#define sipNameNr_1114 1114
#define sipName_1114 &sipStrings_QtDataVisualization[1114]
#define sipNameNr_QtDataVisualization__QAbstract3DAxis__AxisType 1161
#define sipName_QtDataVisualization__QAbstract3DAxis__AxisType &sipStrings_QtDataVisualization[1161]
#define sipNameNr_1208 1208
#define sipName_1208 &sipStrings_QtDataVisualization[1208]
#define sipNameNr_1254 1254
#define sipName_1254 &sipStrings_QtDataVisualization[1254]
#define sipNameNr_QtDataVisualization__QLogValue3DAxisFormatter 1300
#define sipName_QtDataVisualization__QLogValue3DAxisFormatter &sipStrings_QtDataVisualization[1300]
#define sipNameNr_1346 1346
#define sipName_1346 &sipStrings_QtDataVisualization[1346]
#define sipNameNr_QtDataVisualization__Q3DCamera__CameraPreset 1391
#define sipName_QtDataVisualization__Q3DCamera__CameraPreset &sipStrings_QtDataVisualization[1391]
#define sipNameNr_QtDataVisualization__QAbstract3DInputHandler 1436
#define sipName_QtDataVisualization__QAbstract3DInputHandler &sipStrings_QtDataVisualization[1436]
#define sipNameNr_QtDataVisualization__QAbstract3DSeries__Mesh 1481
#define sipName_QtDataVisualization__QAbstract3DSeries__Mesh &sipStrings_QtDataVisualization[1481]
#define sipNameNr_QtDataVisualization__QItemModelBarDataProxy 1526
#define sipName_QtDataVisualization__QItemModelBarDataProxy &sipStrings_QtDataVisualization[1526]
#define sipNameNr_1570 1570
#define sipName_1570 &sipStrings_QtDataVisualization[1570]
#define sipNameNr_1613 1613
#define sipName_1613 &sipStrings_QtDataVisualization[1613]
#define sipNameNr_QtDataVisualization__QValue3DAxisFormatter 1656
#define sipName_QtDataVisualization__QValue3DAxisFormatter &sipStrings_QtDataVisualization[1656]
#define sipNameNr_1699 1699
#define sipName_1699 &sipStrings_QtDataVisualization[1699]
#define sipNameNr_1741 1741
#define sipName_1741 &sipStrings_QtDataVisualization[1741]
#define sipNameNr_QtDataVisualization__Q3DTheme__ColorStyle 1783
#define sipName_QtDataVisualization__Q3DTheme__ColorStyle &sipStrings_QtDataVisualization[1783]
#define sipNameNr_QtDataVisualization__QTouch3DInputHandler 1825
#define sipName_QtDataVisualization__QTouch3DInputHandler &sipStrings_QtDataVisualization[1825]
#define sipNameNr_QtDataVisualization__QAbstractDataProxy 1867
#define sipName_QtDataVisualization__QAbstractDataProxy &sipStrings_QtDataVisualization[1867]
#define sipNameNr_QtDataVisualization__QAbstract3DSeries 1907
#define sipName_QtDataVisualization__QAbstract3DSeries &sipStrings_QtDataVisualization[1907]
#define sipNameNr_QtDataVisualization__QScatterDataProxy 1946
#define sipName_QtDataVisualization__QScatterDataProxy &sipStrings_QtDataVisualization[1946]
#define sipNameNr_QtDataVisualization__QSurfaceDataProxy 1985
#define sipName_QtDataVisualization__QSurfaceDataProxy &sipStrings_QtDataVisualization[1985]
#define sipNameNr_2024 2024
#define sipName_2024 &sipStrings_QtDataVisualization[2024]
#define sipNameNr_QtDataVisualization__QAbstract3DGraph 2062
#define sipName_QtDataVisualization__QAbstract3DGraph &sipStrings_QtDataVisualization[2062]
#define sipNameNr_QtDataVisualization__QScatter3DSeries 2100
#define sipName_QtDataVisualization__QScatter3DSeries &sipStrings_QtDataVisualization[2100]
#define sipNameNr_QtDataVisualization__QScatterDataItem 2138
#define sipName_QtDataVisualization__QScatterDataItem &sipStrings_QtDataVisualization[2138]
#define sipNameNr_QtDataVisualization__QSurface3DSeries 2176
#define sipName_QtDataVisualization__QSurface3DSeries &sipStrings_QtDataVisualization[2176]
#define sipNameNr_QtDataVisualization__QSurfaceDataItem 2214
#define sipName_QtDataVisualization__QSurfaceDataItem &sipStrings_QtDataVisualization[2214]
#define sipNameNr_QtDataVisualization__Q3DInputHandler 2252
#define sipName_QtDataVisualization__Q3DInputHandler &sipStrings_QtDataVisualization[2252]
#define sipNameNr_QtDataVisualization__Q3DTheme__Theme 2289
#define sipName_QtDataVisualization__Q3DTheme__Theme &sipStrings_QtDataVisualization[2289]
#define sipNameNr_QtDataVisualization__QAbstract3DAxis 2326
#define sipName_QtDataVisualization__QAbstract3DAxis &sipStrings_QtDataVisualization[2326]
#define sipNameNr_QtDataVisualization__QCategory3DAxis 2363
#define sipName_QtDataVisualization__QCategory3DAxis &sipStrings_QtDataVisualization[2363]
#define sipNameNr_QtDataVisualization__QCustom3DVolume 2400
#define sipName_QtDataVisualization__QCustom3DVolume &sipStrings_QtDataVisualization[2400]
#define sipNameNr_QtDataVisualization__QCustom3DLabel 2437
#define sipName_QtDataVisualization__QCustom3DLabel &sipStrings_QtDataVisualization[2437]
#define sipNameNr_PYQT_DATAVISUALIZATION_VERSION_STR 2473
#define sipName_PYQT_DATAVISUALIZATION_VERSION_STR &sipStrings_QtDataVisualization[2473]
#define sipNameNr_QtDataVisualization__QBarDataProxy 2508
#define sipName_QtDataVisualization__QBarDataProxy &sipStrings_QtDataVisualization[2508]
#define sipNameNr_QtDataVisualization__QCustom3DItem 2543
#define sipName_QtDataVisualization__QCustom3DItem &sipStrings_QtDataVisualization[2543]
#define sipNameNr_QtDataVisualization__QBar3DSeries 2578
#define sipName_QtDataVisualization__QBar3DSeries &sipStrings_QtDataVisualization[2578]
#define sipNameNr_QtDataVisualization__QBarDataItem 2612
#define sipName_QtDataVisualization__QBarDataItem &sipStrings_QtDataVisualization[2612]
#define sipNameNr_QtDataVisualization__QValue3DAxis 2646
#define sipName_QtDataVisualization__QValue3DAxis &sipStrings_QtDataVisualization[2646]
#define sipNameNr_QTDATAVISUALIZATION_VERSION_STR 2680
#define sipName_QTDATAVISUALIZATION_VERSION_STR &sipStrings_QtDataVisualization[2680]
#define sipNameNr_QtDataVisualization__Q3DScatter 2712
#define sipName_QtDataVisualization__Q3DScatter &sipStrings_QtDataVisualization[2712]
#define sipNameNr_QtDataVisualization__Q3DSurface 2744
#define sipName_QtDataVisualization__Q3DSurface &sipStrings_QtDataVisualization[2744]
#define sipNameNr_CameraPresetDirectlyAboveCCW45 2776
#define sipName_CameraPresetDirectlyAboveCCW45 &sipStrings_QtDataVisualization[2776]
#define sipNameNr_CameraPresetIsometricRightHigh 2807
#define sipName_CameraPresetIsometricRightHigh &sipStrings_QtDataVisualization[2807]
#define sipNameNr_PYQT_DATAVISUALIZATION_VERSION 2838
#define sipName_PYQT_DATAVISUALIZATION_VERSION &sipStrings_QtDataVisualization[2838]
#define sipNameNr_QtDataVisualization__Q3DCamera 2869
#define sipName_QtDataVisualization__Q3DCamera &sipStrings_QtDataVisualization[2869]
#define sipNameNr_QtDataVisualization__Q3DObject 2900
#define sipName_QtDataVisualization__Q3DObject &sipStrings_QtDataVisualization[2900]
#define sipNameNr_singleHighlightGradientChanged 2931
#define sipName_singleHighlightGradientChanged &sipStrings_QtDataVisualization[2931]
#define sipNameNr_CameraPresetDirectlyAboveCW45 2962
#define sipName_CameraPresetDirectlyAboveCW45 &sipStrings_QtDataVisualization[2962]
#define sipNameNr_CameraPresetIsometricLeftHigh 2992
#define sipName_CameraPresetIsometricLeftHigh &sipStrings_QtDataVisualization[2992]
#define sipNameNr_QtDataVisualization__Q3DLight 3022
#define sipName_QtDataVisualization__Q3DLight &sipStrings_QtDataVisualization[3022]
#define sipNameNr_QtDataVisualization__Q3DScene 3052
#define sipName_QtDataVisualization__Q3DScene &sipStrings_QtDataVisualization[3052]
#define sipNameNr_QtDataVisualization__Q3DTheme 3082
#define sipName_QtDataVisualization__Q3DTheme &sipStrings_QtDataVisualization[3082]
#define sipNameNr_highlightLightStrengthChanged 3112
#define sipName_highlightLightStrengthChanged &sipStrings_QtDataVisualization[3112]
#define sipNameNr_labelBackgroundEnabledChanged 3142
#define sipName_labelBackgroundEnabledChanged &sipStrings_QtDataVisualization[3142]
#define sipNameNr_multiHighlightGradientChanged 3172
#define sipName_multiHighlightGradientChanged &sipStrings_QtDataVisualization[3172]
#define sipNameNr_selectionQueryPositionChanged 3202
#define sipName_selectionQueryPositionChanged &sipStrings_QtDataVisualization[3202]
#define sipNameNr_QtDataVisualization__Q3DBars 3232
#define sipName_QtDataVisualization__Q3DBars &sipStrings_QtDataVisualization[3232]
#define sipNameNr_horizontalAspectRatioChanged 3261
#define sipName_horizontalAspectRatioChanged &sipStrings_QtDataVisualization[3261]
#define sipNameNr_secondarySubviewOnTopChanged 3290
#define sipName_secondarySubviewOnTopChanged &sipStrings_QtDataVisualization[3290]
#define sipNameNr_sliceFrameThicknessesChanged 3319
#define sipName_sliceFrameThicknessesChanged &sipStrings_QtDataVisualization[3319]
#define sipNameNr_QTDATAVISUALIZATION_VERSION 3348
#define sipName_QTDATAVISUALIZATION_VERSION &sipStrings_QtDataVisualization[3348]
#define sipNameNr_ambientLightStrengthChanged 3376
#define sipName_ambientLightStrengthChanged &sipStrings_QtDataVisualization[3376]
#define sipNameNr_autoColumnCategoriesChanged 3404
#define sipName_autoColumnCategoriesChanged &sipStrings_QtDataVisualization[3404]
#define sipNameNr_flatShadingSupportedChanged 3432
#define sipName_flatShadingSupportedChanged &sipStrings_QtDataVisualization[3432]
#define sipNameNr_labelBackgroundColorChanged 3460
#define sipName_labelBackgroundColorChanged &sipStrings_QtDataVisualization[3460]
#define sipNameNr_queriedGraphPositionChanged 3488
#define sipName_queriedGraphPositionChanged &sipStrings_QtDataVisualization[3488]
#define sipNameNr_secondarySubViewportChanged 3516
#define sipName_secondarySubViewportChanged &sipStrings_QtDataVisualization[3516]
#define sipNameNr_singleHighlightColorChanged 3544
#define sipName_singleHighlightColorChanged &sipStrings_QtDataVisualization[3544]
#define sipNameNr_CameraPresetIsometricRight 3572
#define sipName_CameraPresetIsometricRight &sipStrings_QtDataVisualization[3572]
#define sipNameNr_QHeightMapSurfaceDataProxy 896
#define sipName_QHeightMapSurfaceDataProxy &sipStrings_QtDataVisualization[896]
#define sipNameNr_QItemModelScatterDataProxy 944
#define sipName_QItemModelScatterDataProxy &sipStrings_QtDataVisualization[944]
#define sipNameNr_QItemModelSurfaceDataProxy 992
#define sipName_QItemModelSurfaceDataProxy &sipStrings_QtDataVisualization[992]
#define sipNameNr_itemLabelVisibilityChanged 3599
#define sipName_itemLabelVisibilityChanged &sipStrings_QtDataVisualization[3599]
#define sipNameNr_multiHighlightColorChanged 3626
#define sipName_multiHighlightColorChanged &sipStrings_QtDataVisualization[3626]
#define sipNameNr_rotationRolePatternChanged 3653
#define sipName_rotationRolePatternChanged &sipStrings_QtDataVisualization[3653]
#define sipNameNr_rotationRoleReplaceChanged 3680
#define sipName_rotationRoleReplaceChanged &sipStrings_QtDataVisualization[3680]
#define sipNameNr_setSingleHighlightGradient 3707
#define sipName_setSingleHighlightGradient &sipStrings_QtDataVisualization[3707]
#define sipNameNr_zoomAtTargetEnabledChanged 3734
#define sipName_zoomAtTargetEnabledChanged &sipStrings_QtDataVisualization[3734]
#define sipNameNr_CameraPresetDirectlyAbove 3761
#define sipName_CameraPresetDirectlyAbove &sipStrings_QtDataVisualization[3761]
#define sipNameNr_CameraPresetDirectlyBelow 3787
#define sipName_CameraPresetDirectlyBelow &sipStrings_QtDataVisualization[3787]
#define sipNameNr_CameraPresetIsometricLeft 3813
#define sipName_CameraPresetIsometricLeft &sipStrings_QtDataVisualization[3813]
#define sipNameNr_PyQt5_QtDataVisualization 3839
#define sipName_PyQt5_QtDataVisualization &sipStrings_QtDataVisualization[3839]
#define sipNameNr_SelectionItemRowAndColumn 3865
#define sipName_SelectionItemRowAndColumn &sipStrings_QtDataVisualization[3865]
#define sipNameNr_activeInputHandlerChanged 3891
#define sipName_activeInputHandlerChanged &sipStrings_QtDataVisualization[3891]
#define sipNameNr_barSpacingRelativeChanged 3917
#define sipName_barSpacingRelativeChanged &sipStrings_QtDataVisualization[3917]
#define sipNameNr_flatShadingEnabledChanged 3943
#define sipName_flatShadingEnabledChanged &sipStrings_QtDataVisualization[3943]
#define sipNameNr_flipHorizontalGridChanged 3969
#define sipName_flipHorizontalGridChanged &sipStrings_QtDataVisualization[3969]
#define sipNameNr_graphPositionQueryChanged 3995
#define sipName_graphPositionQueryChanged &sipStrings_QtDataVisualization[3995]
#define sipNameNr_isPointInSecondarySubView 4021
#define sipName_isPointInSecondarySubView &sipStrings_QtDataVisualization[4021]
#define sipNameNr_labelBorderEnabledChanged 4047
#define sipName_labelBorderEnabledChanged &sipStrings_QtDataVisualization[4047]
#define sipNameNr_multiMatchBehaviorChanged 4073
#define sipName_multiMatchBehaviorChanged &sipStrings_QtDataVisualization[4073]
#define sipNameNr_multiSeriesUniformChanged 4099
#define sipName_multiSeriesUniformChanged &sipStrings_QtDataVisualization[4099]
#define sipNameNr_primarySubViewportChanged 4125
#define sipName_primarySubViewportChanged &sipStrings_QtDataVisualization[4125]
#define sipNameNr_setHighlightLightStrength 4151
#define sipName_setHighlightLightStrength &sipStrings_QtDataVisualization[4151]
#define sipNameNr_setLabelBackgroundEnabled 4177
#define sipName_setLabelBackgroundEnabled &sipStrings_QtDataVisualization[4177]
#define sipNameNr_setMultiHighlightGradient 4203
#define sipName_setMultiHighlightGradient &sipStrings_QtDataVisualization[4203]
#define sipNameNr_setSelectionQueryPosition 4229
#define sipName_setSelectionQueryPosition &sipStrings_QtDataVisualization[4229]
#define sipNameNr_useModelCategoriesChanged 4255
#define sipName_useModelCategoriesChanged &sipStrings_QtDataVisualization[4255]
#define sipNameNr_ColorStyleObjectGradient 4281
#define sipName_ColorStyleObjectGradient &sipStrings_QtDataVisualization[4281]
#define sipNameNr_QLogValue3DAxisFormatter 1321
#define sipName_QLogValue3DAxisFormatter &sipStrings_QtDataVisualization[1321]
#define sipNameNr_autoRowCategoriesChanged 4306
#define sipName_autoRowCategoriesChanged &sipStrings_QtDataVisualization[4306]
#define sipNameNr_backgroundEnabledChanged 4331
#define sipName_backgroundEnabledChanged &sipStrings_QtDataVisualization[4331]
#define sipNameNr_columnRolePatternChanged 4356
#define sipName_columnRolePatternChanged &sipStrings_QtDataVisualization[4356]
#define sipNameNr_columnRoleReplaceChanged 4381
#define sipName_columnRoleReplaceChanged &sipStrings_QtDataVisualization[4381]
#define sipNameNr_invalidSelectionPosition 4406
#define sipName_invalidSelectionPosition &sipStrings_QtDataVisualization[4406]
#define sipNameNr_isLabelBackgroundEnabled 4431
#define sipName_isLabelBackgroundEnabled &sipStrings_QtDataVisualization[4431]
#define sipNameNr_labelAutoRotationChanged 4456
#define sipName_labelAutoRotationChanged &sipStrings_QtDataVisualization[4456]
#define sipNameNr_optimizationHintsChanged 4481
#define sipName_optimizationHintsChanged &sipStrings_QtDataVisualization[4481]
#define sipNameNr_radialLabelOffsetChanged 4506
#define sipName_radialLabelOffsetChanged &sipStrings_QtDataVisualization[4506]
#define sipNameNr_setHorizontalAspectRatio 4531
#define sipName_setHorizontalAspectRatio &sipStrings_QtDataVisualization[4531]
#define sipNameNr_setSecondarySubviewOnTop 4556
#define sipName_setSecondarySubviewOnTop &sipStrings_QtDataVisualization[4556]
#define sipNameNr_setSliceFrameThicknesses 4581
#define sipName_setSliceFrameThicknesses &sipStrings_QtDataVisualization[4581]
#define sipNameNr_CameraPresetBehindBelow 4606
#define sipName_CameraPresetBehindBelow &sipStrings_QtDataVisualization[4606]
#define sipNameNr_ColorStyleRangeGradient 4630
#define sipName_ColorStyleRangeGradient &sipStrings_QtDataVisualization[4630]
#define sipNameNr_DrawSurfaceAndWireframe 4654
#define sipName_DrawSurfaceAndWireframe &sipStrings_QtDataVisualization[4654]
#define sipNameNr_QAbstract3DInputHandler 1457
#define sipName_QAbstract3DInputHandler &sipStrings_QtDataVisualization[1457]
#define sipNameNr_ShadowQualitySoftMedium 4678
#define sipName_ShadowQualitySoftMedium &sipStrings_QtDataVisualization[4678]
#define sipNameNr_columnCategoriesChanged 4702
#define sipName_columnCategoriesChanged &sipStrings_QtDataVisualization[4702]
#define sipNameNr_devicePixelRatioChanged 4726
#define sipName_devicePixelRatioChanged &sipStrings_QtDataVisualization[4726]
#define sipNameNr_isPointInPrimarySubView 4750
#define sipName_isPointInPrimarySubView &sipStrings_QtDataVisualization[4750]
#define sipNameNr_isSecondarySubviewOnTop 4774
#define sipName_isSecondarySubviewOnTop &sipStrings_QtDataVisualization[4774]
#define sipNameNr_positionAbsoluteChanged 4798
#define sipName_positionAbsoluteChanged &sipStrings_QtDataVisualization[4798]
#define sipNameNr_selectedCustomItemIndex 4822
#define sipName_selectedCustomItemIndex &sipStrings_QtDataVisualization[4822]
#define sipNameNr_selectionEnabledChanged 4846
#define sipName_selectionEnabledChanged &sipStrings_QtDataVisualization[4846]
#define sipNameNr_setAmbientLightStrength 4870
#define sipName_setAmbientLightStrength &sipStrings_QtDataVisualization[4870]
#define sipNameNr_setAutoColumnCategories 4894
#define sipName_setAutoColumnCategories &sipStrings_QtDataVisualization[4894]
#define sipNameNr_setLabelBackgroundColor 4918
#define sipName_setLabelBackgroundColor &sipStrings_QtDataVisualization[4918]
#define sipNameNr_setRotationAxisAndAngle 4942
#define sipName_setRotationAxisAndAngle &sipStrings_QtDataVisualization[4942]
#define sipNameNr_setSecondarySubViewport 4966
#define sipName_setSecondarySubViewport &sipStrings_QtDataVisualization[4966]
#define sipNameNr_setSingleHighlightColor 4990
#define sipName_setSingleHighlightColor &sipStrings_QtDataVisualization[4990]
#define sipNameNr_singleHighlightGradient 5014
#define sipName_singleHighlightGradient &sipStrings_QtDataVisualization[5014]
#define sipNameNr_sliceFrameWidthsChanged 5038
#define sipName_sliceFrameWidthsChanged &sipStrings_QtDataVisualization[5038]
#define sipNameNr_useHighDefShaderChanged 5062
#define sipName_useHighDefShaderChanged &sipStrings_QtDataVisualization[5062]
#define sipNameNr_valueRolePatternChanged 5086
#define sipName_valueRolePatternChanged &sipStrings_QtDataVisualization[5086]
#define sipNameNr_valueRoleReplaceChanged 5110
#define sipName_valueRoleReplaceChanged &sipStrings_QtDataVisualization[5110]
#define sipNameNr_CameraPresetBehindHigh 5134
#define sipName_CameraPresetBehindHigh &sipStrings_QtDataVisualization[5134]
#define sipNameNr_CameraPresetFrontBelow 5157
#define sipName_CameraPresetFrontBelow &sipStrings_QtDataVisualization[5157]
#define sipNameNr_CameraPresetRightBelow 5180
#define sipName_CameraPresetRightBelow &sipStrings_QtDataVisualization[5180]
#define sipNameNr_QItemModelBarDataProxy 1547
#define sipName_QItemModelBarDataProxy &sipStrings_QtDataVisualization[1547]
#define sipNameNr_5203 5203
#define sipName_5203 &sipStrings_QtDataVisualization[5203]
#define sipNameNr_5226 5226
#define sipName_5226 &sipStrings_QtDataVisualization[5226]
#define sipNameNr_SelectionItemAndColumn 5249
#define sipName_SelectionItemAndColumn &sipStrings_QtDataVisualization[5249]
#define sipNameNr_alphaMultiplierChanged 5272
#define sipName_alphaMultiplierChanged &sipStrings_QtDataVisualization[5272]
#define sipNameNr_autoAdjustRangeChanged 5295
#define sipName_autoAdjustRangeChanged &sipStrings_QtDataVisualization[5295]
#define sipNameNr_backgroundColorChanged 5318
#define sipName_backgroundColorChanged &sipStrings_QtDataVisualization[5318]
#define sipNameNr_drawSliceFramesChanged 5341
#define sipName_drawSliceFramesChanged &sipStrings_QtDataVisualization[5341]
#define sipNameNr_highlightLightStrength 5364
#define sipName_highlightLightStrength &sipStrings_QtDataVisualization[5364]
#define sipNameNr_isFlatShadingSupported 5387
#define sipName_isFlatShadingSupported &sipStrings_QtDataVisualization[5387]
#define sipNameNr_itemLabelFormatChanged 5410
#define sipName_itemLabelFormatChanged &sipStrings_QtDataVisualization[5410]
#define sipNameNr_multiHighlightGradient 5433
#define sipName_multiHighlightGradient &sipStrings_QtDataVisualization[5433]
#define sipNameNr_orthoProjectionChanged 5456
#define sipName_orthoProjectionChanged &sipStrings_QtDataVisualization[5456]
#define sipNameNr_preserveOpacityChanged 5479
#define sipName_preserveOpacityChanged &sipStrings_QtDataVisualization[5479]
#define sipNameNr_rotationEnabledChanged 5502
#define sipName_rotationEnabledChanged &sipStrings_QtDataVisualization[5502]
#define sipNameNr_scalingAbsoluteChanged 5525
#define sipName_scalingAbsoluteChanged &sipStrings_QtDataVisualization[5525]
#define sipNameNr_selectedElementChanged 5548
#define sipName_selectedElementChanged &sipStrings_QtDataVisualization[5548]
#define sipNameNr_selectionQueryPosition 5571
#define sipName_selectionQueryPosition &sipStrings_QtDataVisualization[5571]
#define sipNameNr_setMultiHighlightColor 5594
#define sipName_setMultiHighlightColor &sipStrings_QtDataVisualization[5594]
#define sipNameNr_setRotationRolePattern 5617
#define sipName_setRotationRolePattern &sipStrings_QtDataVisualization[5617]
#define sipNameNr_setRotationRoleReplace 5640
#define sipName_setRotationRoleReplace &sipStrings_QtDataVisualization[5640]
#define sipNameNr_setZoomAtTargetEnabled 5663
#define sipName_setZoomAtTargetEnabled &sipStrings_QtDataVisualization[5663]
#define sipNameNr_sliceFrameColorChanged 5686
#define sipName_sliceFrameColorChanged &sipStrings_QtDataVisualization[5686]
#define sipNameNr_subSegmentCountChanged 5709
#define sipName_subSegmentCountChanged &sipStrings_QtDataVisualization[5709]
#define sipNameNr_titleVisibilityChanged 5732
#define sipName_titleVisibilityChanged &sipStrings_QtDataVisualization[5732]
#define sipNameNr_userDefinedMeshChanged 5755
#define sipName_userDefinedMeshChanged &sipStrings_QtDataVisualization[5755]
#define sipNameNr_xPosRolePatternChanged 5778
#define sipName_xPosRolePatternChanged &sipStrings_QtDataVisualization[5778]
#define sipNameNr_xPosRoleReplaceChanged 5801
#define sipName_xPosRoleReplaceChanged &sipStrings_QtDataVisualization[5801]
#define sipNameNr_yPosRolePatternChanged 5824
#define sipName_yPosRolePatternChanged &sipStrings_QtDataVisualization[5824]
#define sipNameNr_yPosRoleReplaceChanged 5847
#define sipName_yPosRoleReplaceChanged &sipStrings_QtDataVisualization[5847]
#define sipNameNr_zPosRolePatternChanged 5870
#define sipName_zPosRolePatternChanged &sipStrings_QtDataVisualization[5870]
#define sipNameNr_zPosRoleReplaceChanged 5893
#define sipName_zPosRoleReplaceChanged &sipStrings_QtDataVisualization[5893]
#define sipNameNr_CameraPresetBehindLow 5916
#define sipName_CameraPresetBehindLow &sipStrings_QtDataVisualization[5916]
#define sipNameNr_CameraPresetFrontHigh 5938
#define sipName_CameraPresetFrontHigh &sipStrings_QtDataVisualization[5938]
#define sipNameNr_CameraPresetLeftBelow 5960
#define sipName_CameraPresetLeftBelow &sipStrings_QtDataVisualization[5960]
#define sipNameNr_CameraPresetRightHigh 5982
#define sipName_CameraPresetRightHigh &sipStrings_QtDataVisualization[5982]
#define sipNameNr_QValue3DAxisFormatter 1677
#define sipName_QValue3DAxisFormatter &sipStrings_QtDataVisualization[1677]
#define sipNameNr_SelectionRowAndColumn 6004
#define sipName_SelectionRowAndColumn &sipStrings_QtDataVisualization[6004]
#define sipNameNr_ShadowQualitySoftHigh 6026
#define sipName_ShadowQualitySoftHigh &sipStrings_QtDataVisualization[6026]
#define sipNameNr_horizontalAspectRatio 6048
#define sipName_horizontalAspectRatio &sipStrings_QtDataVisualization[6048]
#define sipNameNr_invalidSelectionIndex 6070
#define sipName_invalidSelectionIndex &sipStrings_QtDataVisualization[6070]
#define sipNameNr_invalidSelectionPoint 6092
#define sipName_invalidSelectionPoint &sipStrings_QtDataVisualization[6092]
#define sipNameNr_isZoomAtTargetEnabled 6114
#define sipName_isZoomAtTargetEnabled &sipStrings_QtDataVisualization[6114]
#define sipNameNr_labelTextColorChanged 6136
#define sipName_labelTextColorChanged &sipStrings_QtDataVisualization[6136]
#define sipNameNr_mouseDoubleClickEvent 6158
#define sipName_mouseDoubleClickEvent &sipStrings_QtDataVisualization[6158]
#define sipNameNr_qDefaultSurfaceFormat 6180
#define sipName_qDefaultSurfaceFormat &sipStrings_QtDataVisualization[6180]
#define sipNameNr_rowRolePatternChanged 6202
#define sipName_rowRolePatternChanged &sipStrings_QtDataVisualization[6202]
#define sipNameNr_rowRoleReplaceChanged 6224
#define sipName_rowRoleReplaceChanged &sipStrings_QtDataVisualization[6224]
#define sipNameNr_selectedSeriesChanged 6246
#define sipName_selectedSeriesChanged &sipStrings_QtDataVisualization[6246]
#define sipNameNr_setActiveInputHandler 6268
#define sipName_setActiveInputHandler &sipStrings_QtDataVisualization[6268]
#define sipNameNr_setBarSpacingRelative 6290
#define sipName_setBarSpacingRelative &sipStrings_QtDataVisualization[6290]
#define sipNameNr_setFlatShadingEnabled 6312
#define sipName_setFlatShadingEnabled &sipStrings_QtDataVisualization[6312]
#define sipNameNr_setFlipHorizontalGrid 6334
#define sipName_setFlipHorizontalGrid &sipStrings_QtDataVisualization[6334]
#define sipNameNr_setGraphPositionQuery 6356
#define sipName_setGraphPositionQuery &sipStrings_QtDataVisualization[6356]
#define sipNameNr_setLabelBorderEnabled 6378
#define sipName_setLabelBorderEnabled &sipStrings_QtDataVisualization[6378]
#define sipNameNr_setMultiMatchBehavior 6400
#define sipName_setMultiMatchBehavior &sipStrings_QtDataVisualization[6400]
#define sipNameNr_setMultiSeriesUniform 6422
#define sipName_setMultiSeriesUniform &sipStrings_QtDataVisualization[6422]
#define sipNameNr_setPrimarySubViewport 6444
#define sipName_setPrimarySubViewport &sipStrings_QtDataVisualization[6444]
#define sipNameNr_setUseModelCategories 6466
#define sipName_setUseModelCategories &sipStrings_QtDataVisualization[6466]
#define sipNameNr_showEdgeLabelsChanged 6488
#define sipName_showEdgeLabelsChanged &sipStrings_QtDataVisualization[6488]
#define sipNameNr_sliceFrameGapsChanged 6510
#define sipName_sliceFrameGapsChanged &sipStrings_QtDataVisualization[6510]
#define sipNameNr_sliceFrameThicknesses 6532
#define sipName_sliceFrameThicknesses &sipStrings_QtDataVisualization[6532]
#define sipNameNr_CameraPresetFrontLow 6554
#define sipName_CameraPresetFrontLow &sipStrings_QtDataVisualization[6554]
#define sipNameNr_CameraPresetLeftHigh 6575
#define sipName_CameraPresetLeftHigh &sipStrings_QtDataVisualization[6575]
#define sipNameNr_CameraPresetRightLow 6596
#define sipName_CameraPresetRightLow &sipStrings_QtDataVisualization[6596]
#define sipNameNr_InputViewOnSecondary 6617
#define sipName_InputViewOnSecondary &sipStrings_QtDataVisualization[6617]
#define sipNameNr_QTouch3DInputHandler 1846
#define sipName_QTouch3DInputHandler &sipStrings_QtDataVisualization[1846]
#define sipNameNr_SelectionMultiSeries 6638
#define sipName_SelectionMultiSeries &sipStrings_QtDataVisualization[6638]
#define sipNameNr_ShadowQualitySoftLow 6659
#define sipName_ShadowQualitySoftLow &sipStrings_QtDataVisualization[6659]
#define sipNameNr_ambientLightStrength 6680
#define sipName_ambientLightStrength &sipStrings_QtDataVisualization[6680]
#define sipNameNr_autoColumnCategories 6701
#define sipName_autoColumnCategories &sipStrings_QtDataVisualization[6701]
#define sipNameNr_baseGradientsChanged 6722
#define sipName_baseGradientsChanged &sipStrings_QtDataVisualization[6722]
#define sipNameNr_borderEnabledChanged 6743
#define sipName_borderEnabledChanged &sipStrings_QtDataVisualization[6743]
#define sipNameNr_gridLineColorChanged 6764
#define sipName_gridLineColorChanged &sipStrings_QtDataVisualization[6764]
#define sipNameNr_heightMapFileChanged 6785
#define sipName_heightMapFileChanged &sipStrings_QtDataVisualization[6785]
#define sipNameNr_isBarSpacingRelative 6806
#define sipName_isBarSpacingRelative &sipStrings_QtDataVisualization[6806]
#define sipNameNr_isFlatShadingEnabled 6827
#define sipName_isFlatShadingEnabled &sipStrings_QtDataVisualization[6827]
#define sipNameNr_isLabelBorderEnabled 6848
#define sipName_isLabelBorderEnabled &sipStrings_QtDataVisualization[6848]
#define sipNameNr_isMultiSeriesUniform 6869
#define sipName_isMultiSeriesUniform &sipStrings_QtDataVisualization[6869]
#define sipNameNr_labelBackgroundColor 6890
#define sipName_labelBackgroundColor &sipStrings_QtDataVisualization[6890]
#define sipNameNr_lightStrengthChanged 6911
#define sipName_lightStrengthChanged &sipStrings_QtDataVisualization[6911]
#define sipNameNr_primarySeriesChanged 6932
#define sipName_primarySeriesChanged &sipStrings_QtDataVisualization[6932]
#define sipNameNr_queriedGraphPosition 6953
#define sipName_queriedGraphPosition &sipStrings_QtDataVisualization[6953]
#define sipNameNr_rowCategoriesChanged 6974
#define sipName_rowCategoriesChanged &sipStrings_QtDataVisualization[6974]
#define sipNameNr_secondarySubViewport 6995
#define sipName_secondarySubViewport &sipStrings_QtDataVisualization[6995]
#define sipNameNr_selectedPointChanged 7016
#define sipName_selectedPointChanged &sipStrings_QtDataVisualization[7016]
#define sipNameNr_selectionModeChanged 7037
#define sipName_selectionModeChanged &sipStrings_QtDataVisualization[7037]
#define sipNameNr_setAutoRowCategories 7058
#define sipName_setAutoRowCategories &sipStrings_QtDataVisualization[7058]
#define sipNameNr_setBackgroundEnabled 7079
#define sipName_setBackgroundEnabled &sipStrings_QtDataVisualization[7079]
#define sipNameNr_setColumnRolePattern 7100
#define sipName_setColumnRolePattern &sipStrings_QtDataVisualization[7100]
#define sipNameNr_setColumnRoleReplace 7121
#define sipName_setColumnRoleReplace &sipStrings_QtDataVisualization[7121]
#define sipNameNr_setLabelAutoRotation 7142
#define sipName_setLabelAutoRotation &sipStrings_QtDataVisualization[7142]
#define sipNameNr_setOptimizationHints 7163
#define sipName_setOptimizationHints &sipStrings_QtDataVisualization[7163]
#define sipNameNr_setRadialLabelOffset 7184
#define sipName_setRadialLabelOffset &sipStrings_QtDataVisualization[7184]
#define sipNameNr_setTextureDimensions 7205
#define sipName_setTextureDimensions &sipStrings_QtDataVisualization[7205]
#define sipNameNr_shadowCastingChanged 7226
#define sipName_shadowCastingChanged &sipStrings_QtDataVisualization[7226]
#define sipNameNr_shadowQualityChanged 7247
#define sipName_shadowQualityChanged &sipStrings_QtDataVisualization[7247]
#define sipNameNr_singleHighlightColor 7268
#define sipName_singleHighlightColor &sipStrings_QtDataVisualization[7268]
#define sipNameNr_slicingActiveChanged 7289
#define sipName_slicingActiveChanged &sipStrings_QtDataVisualization[7289]
#define sipNameNr_textureFormatChanged 7310
#define sipName_textureFormatChanged &sipStrings_QtDataVisualization[7310]
#define sipNameNr_textureHeightChanged 7331
#define sipName_textureHeightChanged &sipStrings_QtDataVisualization[7331]
#define sipNameNr_wrapXRotationChanged 7352
#define sipName_wrapXRotationChanged &sipStrings_QtDataVisualization[7352]
#define sipNameNr_wrapYRotationChanged 7373
#define sipName_wrapYRotationChanged &sipStrings_QtDataVisualization[7373]
#define sipNameNr_AxisOrientationNone 7394
#define sipName_AxisOrientationNone &sipStrings_QtDataVisualization[7394]
#define sipNameNr_CameraPresetLeftLow 7414
#define sipName_CameraPresetLeftLow &sipStrings_QtDataVisualization[7414]
#define sipNameNr_OptimizationDefault 7434
#define sipName_OptimizationDefault &sipStrings_QtDataVisualization[7434]
#define sipNameNr_QtDataVisualization 3845
#define sipName_QtDataVisualization &sipStrings_QtDataVisualization[3845]
#define sipNameNr_SelectionItemAndRow 7454
#define sipName_SelectionItemAndRow &sipStrings_QtDataVisualization[7454]
#define sipNameNr_ShadowQualityMedium 7474
#define sipName_ShadowQualityMedium &sipStrings_QtDataVisualization[7474]
#define sipNameNr_activeCameraChanged 7494
#define sipName_activeCameraChanged &sipStrings_QtDataVisualization[7494]
#define sipNameNr_autoPositionChanged 7514
#define sipName_autoPositionChanged &sipStrings_QtDataVisualization[7514]
#define sipNameNr_barThicknessChanged 7534
#define sipName_barThicknessChanged &sipStrings_QtDataVisualization[7534]
#define sipNameNr_baseGradientChanged 7554
#define sipName_baseGradientChanged &sipStrings_QtDataVisualization[7554]
#define sipNameNr_cameraPresetChanged 7574
#define sipName_cameraPresetChanged &sipStrings_QtDataVisualization[7574]
#define sipNameNr_columnCategoryIndex 7594
#define sipName_columnCategoryIndex &sipStrings_QtDataVisualization[7594]
#define sipNameNr_columnLabelsChanged 7614
#define sipName_columnLabelsChanged &sipStrings_QtDataVisualization[7614]
#define sipNameNr_facingCameraChanged 7634
#define sipName_facingCameraChanged &sipStrings_QtDataVisualization[7634]
#define sipNameNr_isBackgroundEnabled 7654
#define sipName_isBackgroundEnabled &sipStrings_QtDataVisualization[7654]
#define sipNameNr_maxZoomLevelChanged 7674
#define sipName_maxZoomLevelChanged &sipStrings_QtDataVisualization[7674]
#define sipNameNr_meshRotationChanged 7694
#define sipName_meshRotationChanged &sipStrings_QtDataVisualization[7694]
#define sipNameNr_minZoomLevelChanged 7714
#define sipName_minZoomLevelChanged &sipStrings_QtDataVisualization[7714]
#define sipNameNr_multiHighlightColor 7734
#define sipName_multiHighlightColor &sipStrings_QtDataVisualization[7734]
#define sipNameNr_reflectivityChanged 7754
#define sipName_reflectivityChanged &sipStrings_QtDataVisualization[7754]
#define sipNameNr_releaseInputHandler 7774
#define sipName_releaseInputHandler &sipStrings_QtDataVisualization[7774]
#define sipNameNr_rotationRoleChanged 7794
#define sipName_rotationRoleChanged &sipStrings_QtDataVisualization[7794]
#define sipNameNr_rotationRolePattern 7814
#define sipName_rotationRolePattern &sipStrings_QtDataVisualization[7814]
#define sipNameNr_rotationRoleReplace 7834
#define sipName_rotationRoleReplace &sipStrings_QtDataVisualization[7834]
#define sipNameNr_segmentCountChanged 7854
#define sipName_segmentCountChanged &sipStrings_QtDataVisualization[7854]
#define sipNameNr_selectedItemChanged 7874
#define sipName_selectedItemChanged &sipStrings_QtDataVisualization[7874]
#define sipNameNr_setColumnCategories 7894
#define sipName_setColumnCategories &sipStrings_QtDataVisualization[7894]
#define sipNameNr_setDevicePixelRatio 7914
#define sipName_setDevicePixelRatio &sipStrings_QtDataVisualization[7914]
#define sipNameNr_setItemLabelVisible 7934
#define sipName_setItemLabelVisible &sipStrings_QtDataVisualization[7934]
#define sipNameNr_setMeshAxisAndAngle 7954
#define sipName_setMeshAxisAndAngle &sipStrings_QtDataVisualization[7954]
#define sipNameNr_setPositionAbsolute 7974
#define sipName_setPositionAbsolute &sipStrings_QtDataVisualization[7974]
#define sipNameNr_setPreviousInputPos 7994
#define sipName_setPreviousInputPos &sipStrings_QtDataVisualization[7994]
#define sipNameNr_setSelectionEnabled 8014
#define sipName_setSelectionEnabled &sipStrings_QtDataVisualization[8014]
#define sipNameNr_setSliceFrameWidths 8034
#define sipName_setSliceFrameWidths &sipStrings_QtDataVisualization[8034]
#define sipNameNr_setUseHighDefShader 8054
#define sipName_setUseHighDefShader &sipStrings_QtDataVisualization[8054]
#define sipNameNr_setValueRolePattern 8074
#define sipName_setValueRolePattern &sipStrings_QtDataVisualization[8074]
#define sipNameNr_setValueRoleReplace 8094
#define sipName_setValueRoleReplace &sipStrings_QtDataVisualization[8094]
#define sipNameNr_textureDepthChanged 8114
#define sipName_textureDepthChanged &sipStrings_QtDataVisualization[8114]
#define sipNameNr_textureWidthChanged 8134
#define sipName_textureWidthChanged &sipStrings_QtDataVisualization[8134]
#define sipNameNr_CameraPresetBehind 8154
#define sipName_CameraPresetBehind &sipStrings_QtDataVisualization[8154]
#define sipNameNr_InputViewOnPrimary 8173
#define sipName_InputViewOnPrimary &sipStrings_QtDataVisualization[8173]
#define sipNameNr_MultiMatchBehavior 49
#define sipName_MultiMatchBehavior &sipStrings_QtDataVisualization[49]
#define sipNameNr_OptimizationStatic 8192
#define sipName_OptimizationStatic &sipStrings_QtDataVisualization[8192]
#define sipNameNr_QAbstractDataProxy 1888
#define sipName_QAbstractDataProxy &sipStrings_QtDataVisualization[1888]
#define sipNameNr_ThemePrimaryColors 8211
#define sipName_ThemePrimaryColors &sipStrings_QtDataVisualization[8211]
#define sipNameNr_activeInputHandler 8230
#define sipName_activeInputHandler &sipStrings_QtDataVisualization[8230]
#define sipNameNr_activeLightChanged 8249
#define sipName_activeLightChanged &sipStrings_QtDataVisualization[8249]
#define sipNameNr_activeThemeChanged 8268
#define sipName_activeThemeChanged &sipStrings_QtDataVisualization[8268]
#define sipNameNr_aspectRatioChanged 8287
#define sipName_aspectRatioChanged &sipStrings_QtDataVisualization[8287]
#define sipNameNr_autoSubGridChanged 8306
#define sipName_autoSubGridChanged &sipStrings_QtDataVisualization[8306]
#define sipNameNr_columnCountChanged 8325
#define sipName_columnCountChanged &sipStrings_QtDataVisualization[8325]
#define sipNameNr_flipHorizontalGrid 8344
#define sipName_flipHorizontalGrid &sipStrings_QtDataVisualization[8344]
#define sipNameNr_graphPositionQuery 8363
#define sipName_graphPositionQuery &sipStrings_QtDataVisualization[8363]
#define sipNameNr_gridEnabledChanged 8382
#define sipName_gridEnabledChanged &sipStrings_QtDataVisualization[8382]
#define sipNameNr_isItemLabelVisible 8401
#define sipName_isItemLabelVisible &sipStrings_QtDataVisualization[8401]
#define sipNameNr_isPositionAbsolute 8420
#define sipName_isPositionAbsolute &sipStrings_QtDataVisualization[8420]
#define sipNameNr_isSelectionEnabled 8439
#define sipName_isSelectionEnabled &sipStrings_QtDataVisualization[8439]
#define sipNameNr_labelFormatChanged 8458
#define sipName_labelFormatChanged &sipStrings_QtDataVisualization[8458]
#define sipNameNr_multiMatchBehavior 8477
#define sipName_multiMatchBehavior &sipStrings_QtDataVisualization[8477]
#define sipNameNr_orientationChanged 8496
#define sipName_orientationChanged &sipStrings_QtDataVisualization[8496]
#define sipNameNr_primarySubViewport 8515
#define sipName_primarySubViewport &sipStrings_QtDataVisualization[8515]
#define sipNameNr_removeCustomItemAt 8534
#define sipName_removeCustomItemAt &sipStrings_QtDataVisualization[8534]
#define sipNameNr_selectedBarChanged 8553
#define sipName_selectedBarChanged &sipStrings_QtDataVisualization[8553]
#define sipNameNr_selectedCustomItem 8572
#define sipName_selectedCustomItem &sipStrings_QtDataVisualization[8572]
#define sipNameNr_selectedLabelIndex 8591
#define sipName_selectedLabelIndex &sipStrings_QtDataVisualization[8591]
#define sipNameNr_setAlphaMultiplier 8610
#define sipName_setAlphaMultiplier &sipStrings_QtDataVisualization[8610]
#define sipNameNr_setAutoAdjustRange 8629
#define sipName_setAutoAdjustRange &sipStrings_QtDataVisualization[8629]
#define sipNameNr_setBackgroundColor 8648
#define sipName_setBackgroundColor &sipStrings_QtDataVisualization[8648]
#define sipNameNr_setDrawSliceFrames 8667
#define sipName_setDrawSliceFrames &sipStrings_QtDataVisualization[8667]
#define sipNameNr_setItemLabelFormat 8686
#define sipName_setItemLabelFormat &sipStrings_QtDataVisualization[8686]
#define sipNameNr_setOrthoProjection 8705
#define sipName_setOrthoProjection &sipStrings_QtDataVisualization[8705]
#define sipNameNr_setPreserveOpacity 8724
#define sipName_setPreserveOpacity &sipStrings_QtDataVisualization[8724]
#define sipNameNr_setRotationEnabled 8743
#define sipName_setRotationEnabled &sipStrings_QtDataVisualization[8743]
#define sipNameNr_setScalingAbsolute 8762
#define sipName_setScalingAbsolute &sipStrings_QtDataVisualization[8762]
#define sipNameNr_setSliceFrameColor 8781
#define sipName_setSliceFrameColor &sipStrings_QtDataVisualization[8781]
#define sipNameNr_setSubSegmentCount 8800
#define sipName_setSubSegmentCount &sipStrings_QtDataVisualization[8800]
#define sipNameNr_setUserDefinedMesh 8819
#define sipName_setUserDefinedMesh &sipStrings_QtDataVisualization[8819]
#define sipNameNr_setXPosRolePattern 8838
#define sipName_setXPosRolePattern &sipStrings_QtDataVisualization[8838]
#define sipNameNr_setXPosRoleReplace 8857
#define sipName_setXPosRoleReplace &sipStrings_QtDataVisualization[8857]
#define sipNameNr_setYPosRolePattern 8876
#define sipName_setYPosRolePattern &sipStrings_QtDataVisualization[8876]
#define sipNameNr_setYPosRoleReplace 8895
#define sipName_setYPosRoleReplace &sipStrings_QtDataVisualization[8895]
#define sipNameNr_setZPosRolePattern 8914
#define sipName_setZPosRolePattern &sipStrings_QtDataVisualization[8914]
#define sipNameNr_setZPosRoleReplace 8933
#define sipName_setZPosRoleReplace &sipStrings_QtDataVisualization[8933]
#define sipNameNr_sliceIndexXChanged 8952
#define sipName_sliceIndexXChanged &sipStrings_QtDataVisualization[8952]
#define sipNameNr_sliceIndexYChanged 8971
#define sipName_sliceIndexYChanged &sipStrings_QtDataVisualization[8971]
#define sipNameNr_sliceIndexZChanged 8990
#define sipName_sliceIndexZChanged &sipStrings_QtDataVisualization[8990]
#define sipNameNr_textureDataChanged 9009
#define sipName_textureDataChanged &sipStrings_QtDataVisualization[9009]
#define sipNameNr_textureFileChanged 9028
#define sipName_textureFileChanged &sipStrings_QtDataVisualization[9028]
#define sipNameNr_useModelCategories 9047
#define sipName_useModelCategories &sipStrings_QtDataVisualization[9047]
#define sipNameNr_windowColorChanged 9066
#define sipName_windowColorChanged &sipStrings_QtDataVisualization[9066]
#define sipNameNr_zoomEnabledChanged 9085
#define sipName_zoomEnabledChanged &sipStrings_QtDataVisualization[9085]
#define sipNameNr_CameraPresetFront 9104
#define sipName_CameraPresetFront &sipStrings_QtDataVisualization[9104]
#define sipNameNr_CameraPresetRight 9122
#define sipName_CameraPresetRight &sipStrings_QtDataVisualization[9122]
#define sipNameNr_ColorStyleUniform 9140
#define sipName_ColorStyleUniform &sipStrings_QtDataVisualization[9140]
#define sipNameNr_ElementAxisXLabel 9158
#define sipName_ElementAxisXLabel &sipStrings_QtDataVisualization[9158]
#define sipNameNr_ElementAxisYLabel 9176
#define sipName_ElementAxisYLabel &sipStrings_QtDataVisualization[9176]
#define sipNameNr_ElementAxisZLabel 9194
#define sipName_ElementAxisZLabel &sipStrings_QtDataVisualization[9194]
#define sipNameNr_ElementCustomItem 9212
#define sipName_ElementCustomItem &sipStrings_QtDataVisualization[9212]
#define sipNameNr_OptimizationHints 171
#define sipName_OptimizationHints &sipStrings_QtDataVisualization[171]
#define sipNameNr_QAbstract3DSeries 1928
#define sipName_QAbstract3DSeries &sipStrings_QtDataVisualization[1928]
#define sipNameNr_QScatterDataProxy 1967
#define sipName_QScatterDataProxy &sipStrings_QtDataVisualization[1967]
#define sipNameNr_QSurfaceDataProxy 2006
#define sipName_QSurfaceDataProxy &sipStrings_QtDataVisualization[2006]
#define sipNameNr_SeriesTypeScatter 9230
#define sipName_SeriesTypeScatter &sipStrings_QtDataVisualization[9230]
#define sipNameNr_SeriesTypeSurface 9248
#define sipName_SeriesTypeSurface &sipStrings_QtDataVisualization[9248]
#define sipNameNr_ShadowQualityHigh 9266
#define sipName_ShadowQualityHigh &sipStrings_QtDataVisualization[9266]
#define sipNameNr_ShadowQualityNone 9284
#define sipName_ShadowQualityNone &sipStrings_QtDataVisualization[9284]
#define sipNameNr_autoRowCategories 9302
#define sipName_autoRowCategories &sipStrings_QtDataVisualization[9302]
#define sipNameNr_barSpacingChanged 9320
#define sipName_barSpacingChanged &sipStrings_QtDataVisualization[9320]
#define sipNameNr_baseColorsChanged 9338
#define sipName_baseColorsChanged &sipStrings_QtDataVisualization[9338]
#define sipNameNr_colorStyleChanged 9356
#define sipName_colorStyleChanged &sipStrings_QtDataVisualization[9356]
#define sipNameNr_colorTableChanged 9374
#define sipName_colorTableChanged &sipStrings_QtDataVisualization[9374]
#define sipNameNr_columnAxisChanged 9392
#define sipName_columnAxisChanged &sipStrings_QtDataVisualization[9392]
#define sipNameNr_columnRoleChanged 9410
#define sipName_columnRoleChanged &sipStrings_QtDataVisualization[9410]
#define sipNameNr_columnRolePattern 9428
#define sipName_columnRolePattern &sipStrings_QtDataVisualization[9428]
#define sipNameNr_columnRoleReplace 9446
#define sipName_columnRoleReplace &sipStrings_QtDataVisualization[9446]
#define sipNameNr_createNewInstance 9464
#define sipName_createNewInstance &sipStrings_QtDataVisualization[9464]
#define sipNameNr_createTextureData 9482
#define sipName_createTextureData &sipStrings_QtDataVisualization[9482]
#define sipNameNr_currentFpsChanged 9500
#define sipName_currentFpsChanged &sipStrings_QtDataVisualization[9500]
#define sipNameNr_drawSlicesChanged 9518
#define sipName_drawSlicesChanged &sipStrings_QtDataVisualization[9518]
#define sipNameNr_floorLevelChanged 9536
#define sipName_floorLevelChanged &sipStrings_QtDataVisualization[9536]
#define sipNameNr_isAutoAdjustRange 9554
#define sipName_isAutoAdjustRange &sipStrings_QtDataVisualization[9554]
#define sipNameNr_isOrthoProjection 9572
#define sipName_isOrthoProjection &sipStrings_QtDataVisualization[9572]
#define sipNameNr_isRotationEnabled 9590
#define sipName_isRotationEnabled &sipStrings_QtDataVisualization[9590]
#define sipNameNr_isScalingAbsolute 9608
#define sipName_isScalingAbsolute &sipStrings_QtDataVisualization[9608]
#define sipNameNr_labelAutoRotation 9626
#define sipName_labelAutoRotation &sipStrings_QtDataVisualization[9626]
#define sipNameNr_lightColorChanged 3554
#define sipName_lightColorChanged &sipStrings_QtDataVisualization[3554]
#define sipNameNr_measureFpsChanged 9644
#define sipName_measureFpsChanged &sipStrings_QtDataVisualization[9644]
#define sipNameNr_meshSmoothChanged 9662
#define sipName_meshSmoothChanged &sipStrings_QtDataVisualization[9662]
#define sipNameNr_mouseReleaseEvent 9680
#define sipName_mouseReleaseEvent &sipStrings_QtDataVisualization[9680]
#define sipNameNr_optimizationHints 9698
#define sipName_optimizationHints &sipStrings_QtDataVisualization[9698]
#define sipNameNr_radialLabelOffset 9716
#define sipName_radialLabelOffset &sipStrings_QtDataVisualization[9716]
#define sipNameNr_reflectionChanged 9734
#define sipName_reflectionChanged &sipStrings_QtDataVisualization[9734]
#define sipNameNr_releaseCustomItem 9752
#define sipName_releaseCustomItem &sipStrings_QtDataVisualization[9752]
#define sipNameNr_removeCustomItems 9770
#define sipName_removeCustomItems &sipStrings_QtDataVisualization[9770]
#define sipNameNr_setAllowNegatives 9788
#define sipName_setAllowNegatives &sipStrings_QtDataVisualization[9788]
#define sipNameNr_setCameraPosition 9806
#define sipName_setCameraPosition &sipStrings_QtDataVisualization[9806]
#define sipNameNr_setLabelTextColor 9824
#define sipName_setLabelTextColor &sipStrings_QtDataVisualization[9824]
#define sipNameNr_setRowRolePattern 9842
#define sipName_setRowRolePattern &sipStrings_QtDataVisualization[9842]
#define sipNameNr_setRowRoleReplace 9860
#define sipName_setRowRoleReplace &sipStrings_QtDataVisualization[9860]
#define sipNameNr_setShowEdgeLabels 9878
#define sipName_setShowEdgeLabels &sipStrings_QtDataVisualization[9878]
#define sipNameNr_setSliceFrameGaps 9896
#define sipName_setSliceFrameGaps &sipStrings_QtDataVisualization[9896]
#define sipNameNr_setSubTextureData 9914
#define sipName_setSubTextureData &sipStrings_QtDataVisualization[9914]
#define sipNameNr_sip_simplewrapper 9932
#define sipName_sip_simplewrapper &sipStrings_QtDataVisualization[9932]
#define sipNameNr_titleFixedChanged 9950
#define sipName_titleFixedChanged &sipStrings_QtDataVisualization[9950]
#define sipNameNr_visibilityChanged 9968
#define sipName_visibilityChanged &sipStrings_QtDataVisualization[9968]
#define sipNameNr_AxisOrientationX 9986
#define sipName_AxisOrientationX &sipStrings_QtDataVisualization[9986]
#define sipNameNr_AxisOrientationY 10003
#define sipName_AxisOrientationY &sipStrings_QtDataVisualization[10003]
#define sipNameNr_AxisOrientationZ 10020
#define sipName_AxisOrientationZ &sipStrings_QtDataVisualization[10020]
#define sipNameNr_AxisTypeCategory 10037
#define sipName_AxisTypeCategory &sipStrings_QtDataVisualization[10037]
#define sipNameNr_CameraPresetLeft 10054
#define sipName_CameraPresetLeft &sipStrings_QtDataVisualization[10054]
#define sipNameNr_CameraPresetNone 10071
#define sipName_CameraPresetNone &sipStrings_QtDataVisualization[10071]
#define sipNameNr_OptimizationHint 228
#define sipName_OptimizationHint &sipStrings_QtDataVisualization[228]
#define sipNameNr_QAbstract3DGraph 2083
#define sipName_QAbstract3DGraph &sipStrings_QtDataVisualization[2083]
#define sipNameNr_QScatter3DSeries 2121
#define sipName_QScatter3DSeries &sipStrings_QtDataVisualization[2121]
#define sipNameNr_QScatterDataItem 2159
#define sipName_QScatterDataItem &sipStrings_QtDataVisualization[2159]
#define sipNameNr_QSurface3DSeries 2197
#define sipName_QSurface3DSeries &sipStrings_QtDataVisualization[2197]
#define sipNameNr_QSurfaceDataItem 2235
#define sipName_QSurfaceDataItem &sipStrings_QtDataVisualization[2235]
#define sipNameNr_10088 10088
#define sipName_10088 &sipStrings_QtDataVisualization[10088]
#define sipNameNr_ShadowQualityLow 10105
#define sipName_ShadowQualityLow &sipStrings_QtDataVisualization[10105]
#define sipNameNr_ThemeUserDefined 10122
#define sipName_ThemeUserDefined &sipStrings_QtDataVisualization[10122]
#define sipNameNr_baseColorChanged 10139
#define sipName_baseColorChanged &sipStrings_QtDataVisualization[10139]
#define sipNameNr_columnCategories 10156
#define sipName_columnCategories &sipStrings_QtDataVisualization[10156]
#define sipNameNr_dataProxyChanged 10173
#define sipName_dataProxyChanged &sipStrings_QtDataVisualization[10173]
#define sipNameNr_devicePixelRatio 10190
#define sipName_devicePixelRatio &sipStrings_QtDataVisualization[10190]
#define sipNameNr_disconnectNotify 10207
#define sipName_disconnectNotify &sipStrings_QtDataVisualization[10207]
#define sipNameNr_formatterChanged 10224
#define sipName_formatterChanged &sipStrings_QtDataVisualization[10224]
#define sipNameNr_heightMapChanged 10241
#define sipName_heightMapChanged &sipStrings_QtDataVisualization[10241]
#define sipNameNr_inputViewChanged 10258
#define sipName_inputViewChanged &sipStrings_QtDataVisualization[10258]
#define sipNameNr_itemCountChanged 10275
#define sipName_itemCountChanged &sipStrings_QtDataVisualization[10275]
#define sipNameNr_itemLabelChanged 10292
#define sipName_itemLabelChanged &sipStrings_QtDataVisualization[10292]
#define sipNameNr_itemModelChanged 10309
#define sipName_itemModelChanged &sipStrings_QtDataVisualization[10309]
#define sipNameNr_maxXValueChanged 10326
#define sipName_maxXValueChanged &sipStrings_QtDataVisualization[10326]
#define sipNameNr_maxZValueChanged 10343
#define sipName_maxZValueChanged &sipStrings_QtDataVisualization[10343]
#define sipNameNr_meshAngleChanged 10360
#define sipName_meshAngleChanged &sipStrings_QtDataVisualization[10360]
#define sipNameNr_minXValueChanged 10377
#define sipName_minXValueChanged &sipStrings_QtDataVisualization[10377]
#define sipNameNr_minZValueChanged 10394
#define sipName_minZValueChanged &sipStrings_QtDataVisualization[10394]
#define sipNameNr_previousInputPos 10411
#define sipName_previousInputPos &sipStrings_QtDataVisualization[10411]
#define sipNameNr_removeCustomItem 10428
#define sipName_removeCustomItem &sipStrings_QtDataVisualization[10428]
#define sipNameNr_rowCategoryIndex 10445
#define sipName_rowCategoryIndex &sipStrings_QtDataVisualization[10445]
#define sipNameNr_rowLabelsChanged 10462
#define sipName_rowLabelsChanged &sipStrings_QtDataVisualization[10462]
#define sipNameNr_setBaseGradients 10479
#define sipName_setBaseGradients &sipStrings_QtDataVisualization[10479]
#define sipNameNr_setBorderEnabled 10496
#define sipName_setBorderEnabled &sipStrings_QtDataVisualization[10496]
#define sipNameNr_setGridLineColor 10513
#define sipName_setGridLineColor &sipStrings_QtDataVisualization[10513]
#define sipNameNr_setHeightMapFile 10530
#define sipName_setHeightMapFile &sipStrings_QtDataVisualization[10530]
#define sipNameNr_setInputPosition 10547
#define sipName_setInputPosition &sipStrings_QtDataVisualization[10547]
#define sipNameNr_setLightStrength 10564
#define sipName_setLightStrength &sipStrings_QtDataVisualization[10564]
#define sipNameNr_setPrimarySeries 10581
#define sipName_setPrimarySeries &sipStrings_QtDataVisualization[10581]
#define sipNameNr_setRowCategories 10598
#define sipName_setRowCategories &sipStrings_QtDataVisualization[10598]
#define sipNameNr_setSelectedPoint 10615
#define sipName_setSelectedPoint &sipStrings_QtDataVisualization[10615]
#define sipNameNr_setSelectionMode 10632
#define sipName_setSelectionMode &sipStrings_QtDataVisualization[10632]
#define sipNameNr_setShadowCasting 10649
#define sipName_setShadowCasting &sipStrings_QtDataVisualization[10649]
#define sipNameNr_setShadowQuality 10666
#define sipName_setShadowQuality &sipStrings_QtDataVisualization[10666]
#define sipNameNr_setSlicingActive 10683
#define sipName_setSlicingActive &sipStrings_QtDataVisualization[10683]
#define sipNameNr_setTextureFormat 10700
#define sipName_setTextureFormat &sipStrings_QtDataVisualization[10700]
#define sipNameNr_setTextureHeight 10717
#define sipName_setTextureHeight &sipStrings_QtDataVisualization[10717]
#define sipNameNr_setWrapXRotation 10734
#define sipName_setWrapXRotation &sipStrings_QtDataVisualization[10734]
#define sipNameNr_setWrapYRotation 10751
#define sipName_setWrapYRotation &sipStrings_QtDataVisualization[10751]
#define sipNameNr_shadowsSupported 10768
#define sipName_shadowsSupported &sipStrings_QtDataVisualization[10768]
#define sipNameNr_sliceFrameWidths 10785
#define sipName_sliceFrameWidths &sipStrings_QtDataVisualization[10785]
#define sipNameNr_subGridPositions 10802
#define sipName_subGridPositions &sipStrings_QtDataVisualization[10802]
#define sipNameNr_textColorChanged 10819
#define sipName_textColorChanged &sipStrings_QtDataVisualization[10819]
#define sipNameNr_textureDataWidth 10836
#define sipName_textureDataWidth &sipStrings_QtDataVisualization[10836]
#define sipNameNr_useHighDefShader 10853
#define sipName_useHighDefShader &sipStrings_QtDataVisualization[10853]
#define sipNameNr_valueAxisChanged 10870
#define sipName_valueAxisChanged &sipStrings_QtDataVisualization[10870]
#define sipNameNr_valueRoleChanged 10887
#define sipName_valueRoleChanged &sipStrings_QtDataVisualization[10887]
#define sipNameNr_valueRolePattern 10904
#define sipName_valueRolePattern &sipStrings_QtDataVisualization[10904]
#define sipNameNr_valueRoleReplace 10921
#define sipName_valueRoleReplace &sipStrings_QtDataVisualization[10921]
#define sipNameNr_xRotationChanged 10938
#define sipName_xRotationChanged &sipStrings_QtDataVisualization[10938]
#define sipNameNr_yRotationChanged 10955
#define sipName_yRotationChanged &sipStrings_QtDataVisualization[10955]
#define sipNameNr_zoomLevelChanged 10972
#define sipName_zoomLevelChanged &sipStrings_QtDataVisualization[10972]
#define sipNameNr_AxisOrientation 394
#define sipName_AxisOrientation &sipStrings_QtDataVisualization[394]
#define sipNameNr_DataTypeScatter 10989
#define sipName_DataTypeScatter &sipStrings_QtDataVisualization[10989]
#define sipNameNr_DataTypeSurface 11005
#define sipName_DataTypeSurface &sipStrings_QtDataVisualization[11005]
#define sipNameNr_MeshUserDefined 11021
#define sipName_MeshUserDefined &sipStrings_QtDataVisualization[11021]
#define sipNameNr_Q3DInputHandler 2273
#define sipName_Q3DInputHandler &sipStrings_QtDataVisualization[2273]
#define sipNameNr_QAbstract3DAxis 2347
#define sipName_QAbstract3DAxis &sipStrings_QtDataVisualization[2347]
#define sipNameNr_QCategory3DAxis 2384
#define sipName_QCategory3DAxis &sipStrings_QtDataVisualization[2384]
#define sipNameNr_QCustom3DVolume 2421
#define sipName_QCustom3DVolume &sipStrings_QtDataVisualization[2421]
#define sipNameNr_SelectionColumn 11037
#define sipName_SelectionColumn &sipStrings_QtDataVisualization[11037]
#define sipNameNr_addInputHandler 11053
#define sipName_addInputHandler &sipStrings_QtDataVisualization[11053]
#define sipNameNr_alphaMultiplier 11069
#define sipName_alphaMultiplier &sipStrings_QtDataVisualization[11069]
#define sipNameNr_backgroundColor 11085
#define sipName_backgroundColor &sipStrings_QtDataVisualization[11085]
#define sipNameNr_drawModeChanged 11101
#define sipName_drawModeChanged &sipStrings_QtDataVisualization[11101]
#define sipNameNr_drawSliceFrames 11117
#define sipName_drawSliceFrames &sipStrings_QtDataVisualization[11117]
#define sipNameNr_isBorderEnabled 11133
#define sipName_isBorderEnabled &sipStrings_QtDataVisualization[11133]
#define sipNameNr_isShadowCasting 11149
#define sipName_isShadowCasting &sipStrings_QtDataVisualization[11149]
#define sipNameNr_isSlicingActive 11165
#define sipName_isSlicingActive &sipStrings_QtDataVisualization[11165]
#define sipNameNr_itemLabelFormat 11181
#define sipName_itemLabelFormat &sipStrings_QtDataVisualization[11181]
#define sipNameNr_itemSizeChanged 11197
#define sipName_itemSizeChanged &sipStrings_QtDataVisualization[11197]
#define sipNameNr_keyReleaseEvent 11213
#define sipName_keyReleaseEvent &sipStrings_QtDataVisualization[11213]
#define sipNameNr_meshFileChanged 11229
#define sipName_meshFileChanged &sipStrings_QtDataVisualization[11229]
#define sipNameNr_mousePressEvent 11245
#define sipName_mousePressEvent &sipStrings_QtDataVisualization[11245]
#define sipNameNr_positionChanged 11261
#define sipName_positionChanged &sipStrings_QtDataVisualization[11261]
#define sipNameNr_preserveOpacity 11277
#define sipName_preserveOpacity &sipStrings_QtDataVisualization[11277]
#define sipNameNr_reversedChanged 11293
#define sipName_reversedChanged &sipStrings_QtDataVisualization[11293]
#define sipNameNr_rotationChanged 11309
#define sipName_rotationChanged &sipStrings_QtDataVisualization[11309]
#define sipNameNr_rowCountChanged 11325
#define sipName_rowCountChanged &sipStrings_QtDataVisualization[11325]
#define sipNameNr_selectedElement 11341
#define sipName_selectedElement &sipStrings_QtDataVisualization[11341]
#define sipNameNr_setActiveCamera 11357
#define sipName_setActiveCamera &sipStrings_QtDataVisualization[11357]
#define sipNameNr_setAutoPosition 11373
#define sipName_setAutoPosition &sipStrings_QtDataVisualization[11373]
#define sipNameNr_setBarThickness 11389
#define sipName_setBarThickness &sipStrings_QtDataVisualization[11389]
#define sipNameNr_setBaseGradient 11405
#define sipName_setBaseGradient &sipStrings_QtDataVisualization[11405]
#define sipNameNr_setCameraPreset 11421
#define sipName_setCameraPreset &sipStrings_QtDataVisualization[11421]
#define sipNameNr_setColumnLabels 11437
#define sipName_setColumnLabels &sipStrings_QtDataVisualization[11437]
#define sipNameNr_setFacingCamera 11453
#define sipName_setFacingCamera &sipStrings_QtDataVisualization[11453]
#define sipNameNr_setMaxZoomLevel 11469
#define sipName_setMaxZoomLevel &sipStrings_QtDataVisualization[11469]
#define sipNameNr_setMeshRotation 11485
#define sipName_setMeshRotation &sipStrings_QtDataVisualization[11485]
#define sipNameNr_setMinZoomLevel 11501
#define sipName_setMinZoomLevel &sipStrings_QtDataVisualization[11501]
#define sipNameNr_setPrevDistance 11517
#define sipName_setPrevDistance &sipStrings_QtDataVisualization[11517]
#define sipNameNr_setReflectivity 11533
#define sipName_setReflectivity &sipStrings_QtDataVisualization[11533]
#define sipNameNr_setRotationRole 11549
#define sipName_setRotationRole &sipStrings_QtDataVisualization[11549]
#define sipNameNr_setSegmentCount 11565
#define sipName_setSegmentCount &sipStrings_QtDataVisualization[11565]
#define sipNameNr_setSelectedItem 11581
#define sipName_setSelectedItem &sipStrings_QtDataVisualization[11581]
#define sipNameNr_setSliceIndices 11597
#define sipName_setSliceIndices &sipStrings_QtDataVisualization[11597]
#define sipNameNr_setTextureDepth 11613
#define sipName_setTextureDepth &sipStrings_QtDataVisualization[11613]
#define sipNameNr_setTextureImage 11629
#define sipName_setTextureImage &sipStrings_QtDataVisualization[11629]
#define sipNameNr_setTextureWidth 11645
#define sipName_setTextureWidth &sipStrings_QtDataVisualization[11645]
#define sipNameNr_setTitleVisible 11661
#define sipName_setTitleVisible &sipStrings_QtDataVisualization[11661]
#define sipNameNr_sliceFrameColor 11677
#define sipName_sliceFrameColor &sipStrings_QtDataVisualization[11677]
#define sipNameNr_subSegmentCount 11693
#define sipName_subSegmentCount &sipStrings_QtDataVisualization[11693]
#define sipNameNr_userDefinedMesh 11709
#define sipName_userDefinedMesh &sipStrings_QtDataVisualization[11709]
#define sipNameNr_viewportChanged 11725
#define sipName_viewportChanged &sipStrings_QtDataVisualization[11725]
#define sipNameNr_xPosRoleChanged 11741
#define sipName_xPosRoleChanged &sipStrings_QtDataVisualization[11741]
#define sipNameNr_xPosRolePattern 11757
#define sipName_xPosRolePattern &sipStrings_QtDataVisualization[11757]
#define sipNameNr_xPosRoleReplace 11773
#define sipName_xPosRoleReplace &sipStrings_QtDataVisualization[11773]
#define sipNameNr_yPosRoleChanged 11789
#define sipName_yPosRoleChanged &sipStrings_QtDataVisualization[11789]
#define sipNameNr_yPosRolePattern 11805
#define sipName_yPosRolePattern &sipStrings_QtDataVisualization[11805]
#define sipNameNr_yPosRoleReplace 11821
#define sipName_yPosRoleReplace &sipStrings_QtDataVisualization[11821]
#define sipNameNr_zPosRoleChanged 11837
#define sipName_zPosRoleChanged &sipStrings_QtDataVisualization[11837]
#define sipNameNr_zPosRolePattern 11853
#define sipName_zPosRolePattern &sipStrings_QtDataVisualization[11853]
#define sipNameNr_zPosRoleReplace 11869
#define sipName_zPosRoleReplace &sipStrings_QtDataVisualization[11869]
#define sipNameNr_MMBCumulativeY 11885
#define sipName_MMBCumulativeY &sipStrings_QtDataVisualization[11885]
#define sipNameNr_QCustom3DLabel 2458
#define sipName_QCustom3DLabel &sipStrings_QtDataVisualization[2458]
#define sipNameNr_SelectionFlags 449
#define sipName_SelectionFlags &sipStrings_QtDataVisualization[449]
#define sipNameNr_SelectionSlice 11900
#define sipName_SelectionSlice &sipStrings_QtDataVisualization[11900]
#define sipNameNr_SeriesTypeNone 11915
#define sipName_SeriesTypeNone &sipStrings_QtDataVisualization[11915]
#define sipNameNr_ThemeStoneMoss 11930
#define sipName_ThemeStoneMoss &sipStrings_QtDataVisualization[11930]
#define sipNameNr_allowNegatives 11945
#define sipName_allowNegatives &sipStrings_QtDataVisualization[11945]
#define sipNameNr_clearSelection 11960
#define sipName_clearSelection &sipStrings_QtDataVisualization[11960]
#define sipNameNr_copyValuesFrom 11975
#define sipName_copyValuesFrom &sipStrings_QtDataVisualization[11975]
#define sipNameNr_isAutoPosition 11990
#define sipName_isAutoPosition &sipStrings_QtDataVisualization[11990]
#define sipNameNr_isFacingCamera 12005
#define sipName_isFacingCamera &sipStrings_QtDataVisualization[12005]
#define sipNameNr_isTitleVisible 12020
#define sipName_isTitleVisible &sipStrings_QtDataVisualization[12020]
#define sipNameNr_labelPositions 12035
#define sipName_labelPositions &sipStrings_QtDataVisualization[12035]
#define sipNameNr_labelTextColor 12050
#define sipName_labelTextColor &sipStrings_QtDataVisualization[12050]
#define sipNameNr_mouseMoveEvent 12065
#define sipName_mouseMoveEvent &sipStrings_QtDataVisualization[12065]
#define sipNameNr_rowAxisChanged 12080
#define sipName_rowAxisChanged &sipStrings_QtDataVisualization[12080]
#define sipNameNr_rowRoleChanged 12095
#define sipName_rowRoleChanged &sipStrings_QtDataVisualization[12095]
#define sipNameNr_rowRolePattern 12110
#define sipName_rowRolePattern &sipStrings_QtDataVisualization[12110]
#define sipNameNr_rowRoleReplace 12125
#define sipName_rowRoleReplace &sipStrings_QtDataVisualization[12125]
#define sipNameNr_scalingChanged 12140
#define sipName_scalingChanged &sipStrings_QtDataVisualization[12140]
#define sipNameNr_selectedSeries 12155
#define sipName_selectedSeries &sipStrings_QtDataVisualization[12155]
#define sipNameNr_setActiveLight 12170
#define sipName_setActiveLight &sipStrings_QtDataVisualization[12170]
#define sipNameNr_setActiveTheme 12185
#define sipName_setActiveTheme &sipStrings_QtDataVisualization[12185]
#define sipNameNr_setAspectRatio 12200
#define sipName_setAspectRatio &sipStrings_QtDataVisualization[12200]
#define sipNameNr_setAutoSubGrid 12215
#define sipName_setAutoSubGrid &sipStrings_QtDataVisualization[12215]
#define sipNameNr_setGridEnabled 12230
#define sipName_setGridEnabled &sipStrings_QtDataVisualization[12230]
#define sipNameNr_setLabelFormat 12245
#define sipName_setLabelFormat &sipStrings_QtDataVisualization[12245]
#define sipNameNr_setSelectedBar 12260
#define sipName_setSelectedBar &sipStrings_QtDataVisualization[12260]
#define sipNameNr_setSliceIndexX 12275
#define sipName_setSliceIndexX &sipStrings_QtDataVisualization[12275]
#define sipNameNr_setSliceIndexY 12290
#define sipName_setSliceIndexY &sipStrings_QtDataVisualization[12290]
#define sipNameNr_setSliceIndexZ 12305
#define sipName_setSliceIndexZ &sipStrings_QtDataVisualization[12305]
#define sipNameNr_setTextureData 12320
#define sipName_setTextureData &sipStrings_QtDataVisualization[12320]
#define sipNameNr_setTextureFile 12335
#define sipName_setTextureFile &sipStrings_QtDataVisualization[12335]
#define sipNameNr_setValueRanges 12350
#define sipName_setValueRanges &sipStrings_QtDataVisualization[12350]
#define sipNameNr_setWindowColor 12365
#define sipName_setWindowColor &sipStrings_QtDataVisualization[12365]
#define sipNameNr_setZoomEnabled 12380
#define sipName_setZoomEnabled &sipStrings_QtDataVisualization[12380]
#define sipNameNr_showEdgeLabels 12395
#define sipName_showEdgeLabels &sipStrings_QtDataVisualization[12395]
#define sipNameNr_sliceFrameGaps 12410
#define sipName_sliceFrameGaps &sipStrings_QtDataVisualization[12410]
#define sipNameNr_stringForValue 12425
#define sipName_stringForValue &sipStrings_QtDataVisualization[12425]
#define sipNameNr_textureChanged 12440
#define sipName_textureChanged &sipStrings_QtDataVisualization[12440]
#define sipNameNr_visibleChanged 12455
#define sipName_visibleChanged &sipStrings_QtDataVisualization[12455]
#define sipNameNr_AxisTypeValue 12470
#define sipName_AxisTypeValue &sipStrings_QtDataVisualization[12470]
#define sipNameNr_DrawWireframe 12484
#define sipName_DrawWireframe &sipStrings_QtDataVisualization[12484]
#define sipNameNr_ElementSeries 12498
#define sipName_ElementSeries &sipStrings_QtDataVisualization[12498]
#define sipNameNr_InputViewNone 12512
#define sipName_InputViewNone &sipStrings_QtDataVisualization[12512]
#define sipNameNr_MMBCumulative 12526
#define sipName_MMBCumulative &sipStrings_QtDataVisualization[12526]
#define sipNameNr_MeshBevelCube 12540
#define sipName_MeshBevelCube &sipStrings_QtDataVisualization[12540]
#define sipNameNr_QBarDataProxy 2529
#define sipName_QBarDataProxy &sipStrings_QtDataVisualization[2529]
#define sipNameNr_QCustom3DItem 2564
#define sipName_QCustom3DItem &sipStrings_QtDataVisualization[2564]
#define sipNameNr_12554 12554
#define sipName_12554 &sipStrings_QtDataVisualization[12554]
#define sipNameNr_SelectionFlag 556
#define sipName_SelectionFlag &sipStrings_QtDataVisualization[556]
#define sipNameNr_SelectionItem 12568
#define sipName_SelectionItem &sipStrings_QtDataVisualization[12568]
#define sipNameNr_SelectionNone 12582
#define sipName_SelectionNone &sipStrings_QtDataVisualization[12582]
#define sipNameNr_SeriesTypeBar 12596
#define sipName_SeriesTypeBar &sipStrings_QtDataVisualization[12596]
#define sipNameNr_ShadowQuality 609
#define sipName_ShadowQuality &sipStrings_QtDataVisualization[609]
#define sipNameNr_ThemeArmyBlue 12610
#define sipName_ThemeArmyBlue &sipStrings_QtDataVisualization[12610]
#define sipNameNr_ThemeIsabelle 12624
#define sipName_ThemeIsabelle &sipStrings_QtDataVisualization[12624]
#define sipNameNr_addCustomItem 12638
#define sipName_addCustomItem &sipStrings_QtDataVisualization[12638]
#define sipNameNr_baseGradients 12652
#define sipName_baseGradients &sipStrings_QtDataVisualization[12652]
#define sipNameNr_connectNotify 10210
#define sipName_connectNotify &sipStrings_QtDataVisualization[10210]
#define sipNameNr_focusOutEvent 12666
#define sipName_focusOutEvent &sipStrings_QtDataVisualization[12666]
#define sipNameNr_gridLineColor 12680
#define sipName_gridLineColor &sipStrings_QtDataVisualization[12680]
#define sipNameNr_gridPositions 12694
#define sipName_gridPositions &sipStrings_QtDataVisualization[12694]
#define sipNameNr_heightMapFile 12708
#define sipName_heightMapFile &sipStrings_QtDataVisualization[12708]
#define sipNameNr_inputHandlers 12722
#define sipName_inputHandlers &sipStrings_QtDataVisualization[12722]
#define sipNameNr_inputPosition 12736
#define sipName_inputPosition &sipStrings_QtDataVisualization[12736]
#define sipNameNr_isGridEnabled 12750
#define sipName_isGridEnabled &sipStrings_QtDataVisualization[12750]
#define sipNameNr_isZoomEnabled 12764
#define sipName_isZoomEnabled &sipStrings_QtDataVisualization[12764]
#define sipNameNr_itemsInserted 12778
#define sipName_itemsInserted &sipStrings_QtDataVisualization[12778]
#define sipNameNr_keyPressEvent 12792
#define sipName_keyPressEvent &sipStrings_QtDataVisualization[12792]
#define sipNameNr_labelsChanged 12806
#define sipName_labelsChanged &sipStrings_QtDataVisualization[12806]
#define sipNameNr_lightStrength 12820
#define sipName_lightStrength &sipStrings_QtDataVisualization[12820]
#define sipNameNr_localeChanged 12834
#define sipName_localeChanged &sipStrings_QtDataVisualization[12834]
#define sipNameNr_marginChanged 12848
#define sipName_marginChanged &sipStrings_QtDataVisualization[12848]
#define sipNameNr_primarySeries 12862
#define sipName_primarySeries &sipStrings_QtDataVisualization[12862]
#define sipNameNr_renderToImage 12876
#define sipName_renderToImage &sipStrings_QtDataVisualization[12876]
#define sipNameNr_rowCategories 12890
#define sipName_rowCategories &sipStrings_QtDataVisualization[12890]
#define sipNameNr_selectedPoint 12904
#define sipName_selectedPoint &sipStrings_QtDataVisualization[12904]
#define sipNameNr_selectionMode 12918
#define sipName_selectionMode &sipStrings_QtDataVisualization[12918]
#define sipNameNr_seriesChanged 12932
#define sipName_seriesChanged &sipStrings_QtDataVisualization[12932]
#define sipNameNr_setBarSpacing 12946
#define sipName_setBarSpacing &sipStrings_QtDataVisualization[12946]
#define sipNameNr_setBaseColors 12960
#define sipName_setBaseColors &sipStrings_QtDataVisualization[12960]
#define sipNameNr_setColorStyle 12974
#define sipName_setColorStyle &sipStrings_QtDataVisualization[12974]
#define sipNameNr_setColorTable 12988
#define sipName_setColorTable &sipStrings_QtDataVisualization[12988]
#define sipNameNr_setColumnAxis 13002
#define sipName_setColumnAxis &sipStrings_QtDataVisualization[13002]
#define sipNameNr_setColumnRole 13016
#define sipName_setColumnRole &sipStrings_QtDataVisualization[13016]
#define sipNameNr_setDrawSlices 13030
#define sipName_setDrawSlices &sipStrings_QtDataVisualization[13030]
#define sipNameNr_setFloorLevel 13044
#define sipName_setFloorLevel &sipStrings_QtDataVisualization[13044]
#define sipNameNr_setLightColor 13058
#define sipName_setLightColor &sipStrings_QtDataVisualization[13058]
#define sipNameNr_setMeasureFps 13072
#define sipName_setMeasureFps &sipStrings_QtDataVisualization[13072]
#define sipNameNr_setMeshSmooth 13086
#define sipName_setMeshSmooth &sipStrings_QtDataVisualization[13086]
#define sipNameNr_setReflection 13100
#define sipName_setReflection &sipStrings_QtDataVisualization[13100]
#define sipNameNr_setTitleFixed 13114
#define sipName_setTitleFixed &sipStrings_QtDataVisualization[13114]
#define sipNameNr_shadowQuality 13128
#define sipName_shadowQuality &sipStrings_QtDataVisualization[13128]
#define sipNameNr_targetChanged 13142
#define sipName_targetChanged &sipStrings_QtDataVisualization[13142]
#define sipNameNr_textureFormat 13156
#define sipName_textureFormat &sipStrings_QtDataVisualization[13156]
#define sipNameNr_textureHeight 13170
#define sipName_textureHeight &sipStrings_QtDataVisualization[13170]
#define sipNameNr_wrapXRotation 13184
#define sipName_wrapXRotation &sipStrings_QtDataVisualization[13184]
#define sipNameNr_wrapYRotation 13198
#define sipName_wrapYRotation &sipStrings_QtDataVisualization[13198]
#define sipNameNr_AxisTypeNone 13212
#define sipName_AxisTypeNone &sipStrings_QtDataVisualization[13212]
#define sipNameNr_CameraPreset 1423
#define sipName_CameraPreset &sipStrings_QtDataVisualization[1423]
#define sipNameNr_DataTypeNone 13225
#define sipName_DataTypeNone &sipStrings_QtDataVisualization[13225]
#define sipNameNr_MeshBevelBar 13238
#define sipName_MeshBevelBar &sipStrings_QtDataVisualization[13238]
#define sipNameNr_MeshCylinder 13251
#define sipName_MeshCylinder &sipStrings_QtDataVisualization[13251]
#define sipNameNr_QBar3DSeries 2599
#define sipName_QBar3DSeries &sipStrings_QtDataVisualization[2599]
#define sipNameNr_QBarDataItem 2633
#define sipName_QBarDataItem &sipStrings_QtDataVisualization[2633]
#define sipNameNr_QValue3DAxis 2667
#define sipName_QValue3DAxis &sipStrings_QtDataVisualization[2667]
#define sipNameNr_SelectionRow 13264
#define sipName_SelectionRow &sipStrings_QtDataVisualization[13264]
#define sipNameNr_activeCamera 13277
#define sipName_activeCamera &sipStrings_QtDataVisualization[13277]
#define sipNameNr_axisXChanged 13290
#define sipName_axisXChanged &sipStrings_QtDataVisualization[13290]
#define sipNameNr_axisYChanged 13303
#define sipName_axisYChanged &sipStrings_QtDataVisualization[13303]
#define sipNameNr_axisZChanged 13316
#define sipName_axisZChanged &sipStrings_QtDataVisualization[13316]
#define sipNameNr_barThickness 13329
#define sipName_barThickness &sipStrings_QtDataVisualization[13329]
#define sipNameNr_baseGradient 13342
#define sipName_baseGradient &sipStrings_QtDataVisualization[13342]
#define sipNameNr_cameraPreset 13355
#define sipName_cameraPreset &sipStrings_QtDataVisualization[13355]
#define sipNameNr_columnLabels 13368
#define sipName_columnLabels &sipStrings_QtDataVisualization[13368]
#define sipNameNr_focusInEvent 13381
#define sipName_focusInEvent &sipStrings_QtDataVisualization[13381]
#define sipNameNr_insertSeries 13394
#define sipName_insertSeries &sipStrings_QtDataVisualization[13394]
#define sipNameNr_isMeshSmooth 13407
#define sipName_isMeshSmooth &sipStrings_QtDataVisualization[13407]
#define sipNameNr_isReflection 13420
#define sipName_isReflection &sipStrings_QtDataVisualization[13420]
#define sipNameNr_isTitleFixed 13433
#define sipName_isTitleFixed &sipStrings_QtDataVisualization[13433]
#define sipNameNr_itemsChanged 13446
#define sipName_itemsChanged &sipStrings_QtDataVisualization[13446]
#define sipNameNr_itemsRemoved 13459
#define sipName_itemsRemoved &sipStrings_QtDataVisualization[13459]
#define sipNameNr_labelStrings 13472
#define sipName_labelStrings &sipStrings_QtDataVisualization[13472]
#define sipNameNr_labelsChange 13485
#define sipName_labelsChange &sipStrings_QtDataVisualization[13485]
#define sipNameNr_maxZoomLevel 13498
#define sipName_maxZoomLevel &sipStrings_QtDataVisualization[13498]
#define sipNameNr_meshRotation 13511
#define sipName_meshRotation &sipStrings_QtDataVisualization[13511]
#define sipNameNr_minZoomLevel 13524
#define sipName_minZoomLevel &sipStrings_QtDataVisualization[13524]
#define sipNameNr_polarChanged 13537
#define sipName_polarChanged &sipStrings_QtDataVisualization[13537]
#define sipNameNr_populateCopy 13550
#define sipName_populateCopy &sipStrings_QtDataVisualization[13550]
#define sipNameNr_prevDistance 13563
#define sipName_prevDistance &sipStrings_QtDataVisualization[13563]
#define sipNameNr_rangeChanged 13576
#define sipName_rangeChanged &sipStrings_QtDataVisualization[13576]
#define sipNameNr_reflectivity 13589
#define sipName_reflectivity &sipStrings_QtDataVisualization[13589]
#define sipNameNr_releaseTheme 13602
#define sipName_releaseTheme &sipStrings_QtDataVisualization[13602]
#define sipNameNr_removeLabels 13615
#define sipName_removeLabels &sipStrings_QtDataVisualization[13615]
#define sipNameNr_removeSeries 13628
#define sipName_removeSeries &sipStrings_QtDataVisualization[13628]
#define sipNameNr_rotationRole 13641
#define sipName_rotationRole &sipStrings_QtDataVisualization[13641]
#define sipNameNr_rowsInserted 13654
#define sipName_rowsInserted &sipStrings_QtDataVisualization[13654]
#define sipNameNr_sceneChanged 13667
#define sipName_sceneChanged &sipStrings_QtDataVisualization[13667]
#define sipNameNr_segmentCount 13680
#define sipName_segmentCount &sipStrings_QtDataVisualization[13680]
#define sipNameNr_selectedAxis 13693
#define sipName_selectedAxis &sipStrings_QtDataVisualization[13693]
#define sipNameNr_selectedItem 13706
#define sipName_selectedItem &sipStrings_QtDataVisualization[13706]
#define sipNameNr_setAllowZero 13719
#define sipName_setAllowZero &sipStrings_QtDataVisualization[13719]
#define sipNameNr_setBaseColor 13732
#define sipName_setBaseColor &sipStrings_QtDataVisualization[13732]
#define sipNameNr_setDataProxy 13745
#define sipName_setDataProxy &sipStrings_QtDataVisualization[13745]
#define sipNameNr_setFormatter 13758
#define sipName_setFormatter &sipStrings_QtDataVisualization[13758]
#define sipNameNr_setHeightMap 13771
#define sipName_setHeightMap &sipStrings_QtDataVisualization[13771]
#define sipNameNr_setInputView 13784
#define sipName_setInputView &sipStrings_QtDataVisualization[13784]
#define sipNameNr_setItemModel 13797
#define sipName_setItemModel &sipStrings_QtDataVisualization[13797]
#define sipNameNr_setMaxXValue 13810
#define sipName_setMaxXValue &sipStrings_QtDataVisualization[13810]
#define sipNameNr_setMaxZValue 13823
#define sipName_setMaxZValue &sipStrings_QtDataVisualization[13823]
#define sipNameNr_setMeshAngle 13836
#define sipName_setMeshAngle &sipStrings_QtDataVisualization[13836]
#define sipNameNr_setMinXValue 13849
#define sipName_setMinXValue &sipStrings_QtDataVisualization[13849]
#define sipNameNr_setMinZValue 13862
#define sipName_setMinZValue &sipStrings_QtDataVisualization[13862]
#define sipNameNr_setRowLabels 13875
#define sipName_setRowLabels &sipStrings_QtDataVisualization[13875]
#define sipNameNr_setTextColor 13888
#define sipName_setTextColor &sipStrings_QtDataVisualization[13888]
#define sipNameNr_setValueAxis 13901
#define sipName_setValueAxis &sipStrings_QtDataVisualization[13901]
#define sipNameNr_setValueRole 13914
#define sipName_setValueRole &sipStrings_QtDataVisualization[13914]
#define sipNameNr_setXRotation 13927
#define sipName_setXRotation &sipStrings_QtDataVisualization[13927]
#define sipNameNr_setYRotation 13940
#define sipName_setYRotation &sipStrings_QtDataVisualization[13940]
#define sipNameNr_setZoomLevel 13953
#define sipName_setZoomLevel &sipStrings_QtDataVisualization[13953]
#define sipNameNr_textureDepth 13966
#define sipName_textureDepth &sipStrings_QtDataVisualization[13966]
#define sipNameNr_textureWidth 13979
#define sipName_textureWidth &sipStrings_QtDataVisualization[13979]
#define sipNameNr_titleChanged 13992
#define sipName_titleChanged &sipStrings_QtDataVisualization[13992]
#define sipNameNr_DataTypeBar 14005
#define sipName_DataTypeBar &sipStrings_QtDataVisualization[14005]
#define sipNameNr_DrawSurface 14017
#define sipName_DrawSurface &sipStrings_QtDataVisualization[14017]
#define sipNameNr_ElementNone 14029
#define sipName_ElementNone &sipStrings_QtDataVisualization[14029]
#define sipNameNr_ElementType 713
#define sipName_ElementType &sipStrings_QtDataVisualization[713]
#define sipNameNr_MeshMinimal 14041
#define sipName_MeshMinimal &sipStrings_QtDataVisualization[14041]
#define sipNameNr_MeshPyramid 14053
#define sipName_MeshPyramid &sipStrings_QtDataVisualization[14053]
#define sipNameNr_activeLight 14065
#define sipName_activeLight &sipStrings_QtDataVisualization[14065]
#define sipNameNr_activeTheme 14077
#define sipName_activeTheme &sipStrings_QtDataVisualization[14077]
#define sipNameNr_aspectRatio 14089
#define sipName_aspectRatio &sipStrings_QtDataVisualization[14089]
#define sipNameNr_autoSubGrid 14101
#define sipName_autoSubGrid &sipStrings_QtDataVisualization[14101]
#define sipNameNr_baseChanged 14113
#define sipName_baseChanged &sipStrings_QtDataVisualization[14113]
#define sipNameNr_columnCount 14125
#define sipName_columnCount &sipStrings_QtDataVisualization[14125]
#define sipNameNr_customEvent 14137
#define sipName_customEvent &sipStrings_QtDataVisualization[14137]
#define sipNameNr_customItems 14149
#define sipName_customItems &sipStrings_QtDataVisualization[14149]
#define sipNameNr_eventFilter 14161
#define sipName_eventFilter &sipStrings_QtDataVisualization[14161]
#define sipNameNr_exposeEvent 14173
#define sipName_exposeEvent &sipStrings_QtDataVisualization[14173]
#define sipNameNr_focusObject 14185
#define sipName_focusObject &sipStrings_QtDataVisualization[14185]
#define sipNameNr_fontChanged 14197
#define sipName_fontChanged &sipStrings_QtDataVisualization[14197]
#define sipNameNr_insertItems 14209
#define sipName_insertItems &sipStrings_QtDataVisualization[14209]
#define sipNameNr_itemChanged 14221
#define sipName_itemChanged &sipStrings_QtDataVisualization[14221]
#define sipNameNr_labelFormat 14233
#define sipName_labelFormat &sipStrings_QtDataVisualization[14233]
#define sipNameNr_meshChanged 14245
#define sipName_meshChanged &sipStrings_QtDataVisualization[14245]
#define sipNameNr_msaaSamples 14257
#define sipName_msaaSamples &sipStrings_QtDataVisualization[14257]
#define sipNameNr_nameChanged 14269
#define sipName_nameChanged &sipStrings_QtDataVisualization[14269]
#define sipNameNr_orientation 14281
#define sipName_orientation &sipStrings_QtDataVisualization[14281]
#define sipNameNr_parentScene 14293
#define sipName_parentScene &sipStrings_QtDataVisualization[14293]
#define sipNameNr_recalculate 14305
#define sipName_recalculate &sipStrings_QtDataVisualization[14305]
#define sipNameNr_releaseAxis 14317
#define sipName_releaseAxis &sipStrings_QtDataVisualization[14317]
#define sipNameNr_removeItems 14329
#define sipName_removeItems &sipStrings_QtDataVisualization[14329]
#define sipNameNr_renderSlice 14341
#define sipName_renderSlice &sipStrings_QtDataVisualization[14341]
#define sipNameNr_resizeEvent 14353
#define sipName_resizeEvent &sipStrings_QtDataVisualization[14353]
#define sipNameNr_rowsChanged 14365
#define sipName_rowsChanged &sipStrings_QtDataVisualization[14365]
#define sipNameNr_rowsRemoved 14377
#define sipName_rowsRemoved &sipStrings_QtDataVisualization[14377]
#define sipNameNr_selectedBar 14389
#define sipName_selectedBar &sipStrings_QtDataVisualization[14389]
#define sipNameNr_setDrawMode 14401
#define sipName_setDrawMode &sipStrings_QtDataVisualization[14401]
#define sipNameNr_setItemSize 14413
#define sipName_setItemSize &sipStrings_QtDataVisualization[14413]
#define sipNameNr_setMeshFile 14425
#define sipName_setMeshFile &sipStrings_QtDataVisualization[14425]
#define sipNameNr_setPosition 14437
#define sipName_setPosition &sipStrings_QtDataVisualization[14437]
#define sipNameNr_setReversed 14449
#define sipName_setReversed &sipStrings_QtDataVisualization[14449]
#define sipNameNr_setRotation 14461
#define sipName_setRotation &sipStrings_QtDataVisualization[14461]
#define sipNameNr_setXPosRole 14473
#define sipName_setXPosRole &sipStrings_QtDataVisualization[14473]
#define sipNameNr_setYPosRole 14485
#define sipName_setYPosRole &sipStrings_QtDataVisualization[14485]
#define sipNameNr_setZPosRole 14497
#define sipName_setZPosRole &sipStrings_QtDataVisualization[14497]
#define sipNameNr_sliceIndexX 14509
#define sipName_sliceIndexX &sipStrings_QtDataVisualization[14509]
#define sipNameNr_sliceIndexY 14521
#define sipName_sliceIndexY &sipStrings_QtDataVisualization[14521]
#define sipNameNr_sliceIndexZ 14533
#define sipName_sliceIndexZ &sipStrings_QtDataVisualization[14533]
#define sipNameNr_surfaceType 14545
#define sipName_surfaceType &sipStrings_QtDataVisualization[14545]
#define sipNameNr_tabletEvent 14557
#define sipName_tabletEvent &sipStrings_QtDataVisualization[14557]
#define sipNameNr_textChanged 14569
#define sipName_textChanged &sipStrings_QtDataVisualization[14569]
#define sipNameNr_textureData 14581
#define sipName_textureData &sipStrings_QtDataVisualization[14581]
#define sipNameNr_textureFile 14593
#define sipName_textureFile &sipStrings_QtDataVisualization[14593]
#define sipNameNr_typeChanged 14605
#define sipName_typeChanged &sipStrings_QtDataVisualization[14605]
#define sipNameNr_windowColor 14617
#define sipName_windowColor &sipStrings_QtDataVisualization[14617]
#define sipNameNr_ColorStyle 1814
#define sipName_ColorStyle &sipStrings_QtDataVisualization[1814]
#define sipNameNr_MMBAverage 14629
#define sipName_MMBAverage &sipStrings_QtDataVisualization[14629]
#define sipNameNr_MeshSphere 14640
#define sipName_MeshSphere &sipStrings_QtDataVisualization[14640]
#define sipNameNr_Q3DScatter 2733
#define sipName_Q3DScatter &sipStrings_QtDataVisualization[2733]
#define sipNameNr_Q3DSurface 2765
#define sipName_Q3DSurface &sipStrings_QtDataVisualization[2765]
#define sipNameNr_SeriesType 765
#define sipName_SeriesType &sipStrings_QtDataVisualization[765]
#define sipNameNr_ThemeDigia 14651
#define sipName_ThemeDigia &sipStrings_QtDataVisualization[14651]
#define sipNameNr_ThemeEbony 14662
#define sipName_ThemeEbony &sipStrings_QtDataVisualization[14662]
#define sipNameNr_ThemeRetro 14673
#define sipName_ThemeRetro &sipStrings_QtDataVisualization[14673]
#define sipNameNr___invert__ 14684
#define sipName___invert__ &sipStrings_QtDataVisualization[14684]
#define sipNameNr_arrayReset 14695
#define sipName_arrayReset &sipStrings_QtDataVisualization[14695]
#define sipNameNr_barSpacing 14706
#define sipName_barSpacing &sipStrings_QtDataVisualization[14706]
#define sipNameNr_baseColors 14717
#define sipName_baseColors &sipStrings_QtDataVisualization[14717]
#define sipNameNr_childEvent 14728
#define sipName_childEvent &sipStrings_QtDataVisualization[14728]
#define sipNameNr_colorStyle 14739
#define sipName_colorStyle &sipStrings_QtDataVisualization[14739]
#define sipNameNr_colorTable 14750
#define sipName_colorTable &sipStrings_QtDataVisualization[14750]
#define sipNameNr_columnAxis 14761
#define sipName_columnAxis &sipStrings_QtDataVisualization[14761]
#define sipNameNr_columnRole 14772
#define sipName_columnRole &sipStrings_QtDataVisualization[14772]
#define sipNameNr_currentFps 14783
#define sipName_currentFps &sipStrings_QtDataVisualization[14783]
#define sipNameNr_drawSlices 14794
#define sipName_drawSlices &sipStrings_QtDataVisualization[14794]
#define sipNameNr_floorLevel 14805
#define sipName_floorLevel &sipStrings_QtDataVisualization[14805]
#define sipNameNr_hasContext 14816
#define sipName_hasContext &sipStrings_QtDataVisualization[14816]
#define sipNameNr_insertItem 14827
#define sipName_insertItem &sipStrings_QtDataVisualization[14827]
#define sipNameNr_insertRows 14838
#define sipName_insertRows &sipStrings_QtDataVisualization[14838]
#define sipNameNr_itemsAdded 14849
#define sipName_itemsAdded &sipStrings_QtDataVisualization[14849]
#define sipNameNr_lightColor 5003
#define sipName_lightColor &sipStrings_QtDataVisualization[5003]
#define sipNameNr_maxChanged 14860
#define sipName_maxChanged &sipStrings_QtDataVisualization[14860]
#define sipNameNr_measureFps 14871
#define sipName_measureFps &sipStrings_QtDataVisualization[14871]
#define sipNameNr_minChanged 14882
#define sipName_minChanged &sipStrings_QtDataVisualization[14882]
#define sipNameNr_positionAt 14893
#define sipName_positionAt &sipStrings_QtDataVisualization[14893]
#define sipNameNr_removeRows 14904
#define sipName_removeRows &sipStrings_QtDataVisualization[14904]
#define sipNameNr_resetArray 14915
#define sipName_resetArray &sipStrings_QtDataVisualization[14915]
#define sipNameNr_seriesList 14926
#define sipName_seriesList &sipStrings_QtDataVisualization[14926]
#define sipNameNr_setRowAxis 14937
#define sipName_setRowAxis &sipStrings_QtDataVisualization[14937]
#define sipNameNr_setRowRole 14948
#define sipName_setRowRole &sipStrings_QtDataVisualization[14948]
#define sipNameNr_setScaling 14959
#define sipName_setScaling &sipStrings_QtDataVisualization[14959]
#define sipNameNr_setTexture 14970
#define sipName_setTexture &sipStrings_QtDataVisualization[14970]
#define sipNameNr_setVisible 14981
#define sipName_setVisible &sipStrings_QtDataVisualization[14981]
#define sipNameNr_timerEvent 14992
#define sipName_timerEvent &sipStrings_QtDataVisualization[14992]
#define sipNameNr_touchEvent 15003
#define sipName_touchEvent &sipStrings_QtDataVisualization[15003]
#define sipNameNr_wheelEvent 15014
#define sipName_wheelEvent &sipStrings_QtDataVisualization[15014]
#define sipNameNr_DrawFlags 865
#define sipName_DrawFlags &sipStrings_QtDataVisualization[865]
#define sipNameNr_InputView 291
#define sipName_InputView &sipStrings_QtDataVisualization[291]
#define sipNameNr_MeshArrow 15025
#define sipName_MeshArrow &sipStrings_QtDataVisualization[15025]
#define sipNameNr_MeshPoint 15035
#define sipName_MeshPoint &sipStrings_QtDataVisualization[15035]
#define sipNameNr_Q3DCamera 2890
#define sipName_Q3DCamera &sipStrings_QtDataVisualization[2890]
#define sipNameNr_Q3DObject 2921
#define sipName_Q3DObject &sipStrings_QtDataVisualization[2921]
#define sipNameNr___index__ 15045
#define sipName___index__ &sipStrings_QtDataVisualization[15045]
#define sipNameNr_addSeries 15055
#define sipName_addSeries &sipStrings_QtDataVisualization[15055]
#define sipNameNr_allowZero 15065
#define sipName_allowZero &sipStrings_QtDataVisualization[15065]
#define sipNameNr_antialias 15075
#define sipName_antialias &sipStrings_QtDataVisualization[15075]
#define sipNameNr_baseColor 15085
#define sipName_baseColor &sipStrings_QtDataVisualization[15085]
#define sipNameNr_dataProxy 15095
#define sipName_dataProxy &sipStrings_QtDataVisualization[15095]
#define sipNameNr_formatter 15105
#define sipName_formatter &sipStrings_QtDataVisualization[15105]
#define sipNameNr_heightMap 15115
#define sipName_heightMap &sipStrings_QtDataVisualization[15115]
#define sipNameNr_hideEvent 15125
#define sipName_hideEvent &sipStrings_QtDataVisualization[15125]
#define sipNameNr_imageSize 15135
#define sipName_imageSize &sipStrings_QtDataVisualization[15135]
#define sipNameNr_inputView 15145
#define sipName_inputView &sipStrings_QtDataVisualization[15145]
#define sipNameNr_insertRow 15155
#define sipName_insertRow &sipStrings_QtDataVisualization[15155]
#define sipNameNr_isVisible 15165
#define sipName_isVisible &sipStrings_QtDataVisualization[15165]
#define sipNameNr_itemCount 15175
#define sipName_itemCount &sipStrings_QtDataVisualization[15175]
#define sipNameNr_itemLabel 15185
#define sipName_itemLabel &sipStrings_QtDataVisualization[15185]
#define sipNameNr_itemModel 15195
#define sipName_itemModel &sipStrings_QtDataVisualization[15195]
#define sipNameNr_markDirty 15205
#define sipName_markDirty &sipStrings_QtDataVisualization[15205]
#define sipNameNr_maxXValue 15215
#define sipName_maxXValue &sipStrings_QtDataVisualization[15215]
#define sipNameNr_maxZValue 15225
#define sipName_maxZValue &sipStrings_QtDataVisualization[15225]
#define sipNameNr_meshAngle 15235
#define sipName_meshAngle &sipStrings_QtDataVisualization[15235]
#define sipNameNr_minXValue 15245
#define sipName_minXValue &sipStrings_QtDataVisualization[15245]
#define sipNameNr_minZValue 15255
#define sipName_minZValue &sipStrings_QtDataVisualization[15255]
#define sipNameNr_moveEvent 15265
#define sipName_moveEvent &sipStrings_QtDataVisualization[15265]
#define sipNameNr_rowLabels 15275
#define sipName_rowLabels &sipStrings_QtDataVisualization[15275]
#define sipNameNr_rowsAdded 15285
#define sipName_rowsAdded &sipStrings_QtDataVisualization[15285]
#define sipNameNr_setLabels 15295
#define sipName_setLabels &sipStrings_QtDataVisualization[15295]
#define sipNameNr_setLocale 15305
#define sipName_setLocale &sipStrings_QtDataVisualization[15305]
#define sipNameNr_setMargin 15315
#define sipName_setMargin &sipStrings_QtDataVisualization[15315]
#define sipNameNr_setTarget 15325
#define sipName_setTarget &sipStrings_QtDataVisualization[15325]
#define sipNameNr_showEvent 15335
#define sipName_showEvent &sipStrings_QtDataVisualization[15335]
#define sipNameNr_textColor 15345
#define sipName_textColor &sipStrings_QtDataVisualization[15345]
#define sipNameNr_valueAxis 15355
#define sipName_valueAxis &sipStrings_QtDataVisualization[15355]
#define sipNameNr_valueRole 15365
#define sipName_valueRole &sipStrings_QtDataVisualization[15365]
#define sipNameNr_xRotation 15375
#define sipName_xRotation &sipStrings_QtDataVisualization[15375]
#define sipNameNr_yRotation 15385
#define sipName_yRotation &sipStrings_QtDataVisualization[15385]
#define sipNameNr_zoomLevel 15395
#define sipName_zoomLevel &sipStrings_QtDataVisualization[15395]
#define sipNameNr_AxisType 1199
#define sipName_AxisType &sipStrings_QtDataVisualization[1199]
#define sipNameNr_DataType 817
#define sipName_DataType &sipStrings_QtDataVisualization[817]
#define sipNameNr_DrawFlag 1058
#define sipName_DrawFlag &sipStrings_QtDataVisualization[1058]
#define sipNameNr_MMBFirst 15405
#define sipName_MMBFirst &sipStrings_QtDataVisualization[15405]
#define sipNameNr_MeshCone 15414
#define sipName_MeshCone &sipStrings_QtDataVisualization[15414]
#define sipNameNr_MeshCube 15423
#define sipName_MeshCube &sipStrings_QtDataVisualization[15423]
#define sipNameNr_Q3DLight 3043
#define sipName_Q3DLight &sipStrings_QtDataVisualization[3043]
#define sipNameNr_Q3DScene 3073
#define sipName_Q3DScene &sipStrings_QtDataVisualization[3073]
#define sipNameNr_Q3DTheme 3103
#define sipName_Q3DTheme &sipStrings_QtDataVisualization[3103]
#define sipNameNr___bool__ 15432
#define sipName___bool__ &sipStrings_QtDataVisualization[15432]
#define sipNameNr___hash__ 15441
#define sipName___hash__ &sipStrings_QtDataVisualization[15441]
#define sipNameNr___iand__ 15450
#define sipName___iand__ &sipStrings_QtDataVisualization[15450]
#define sipNameNr___ixor__ 15459
#define sipName___ixor__ &sipStrings_QtDataVisualization[15459]
#define sipNameNr_addItems 15468
#define sipName_addItems &sipStrings_QtDataVisualization[15468]
#define sipNameNr_addTheme 15477
#define sipName_addTheme &sipStrings_QtDataVisualization[15477]
#define sipNameNr_drawMode 15486
#define sipName_drawMode &sipStrings_QtDataVisualization[15486]
#define sipNameNr_itemSize 15495
#define sipName_itemSize &sipStrings_QtDataVisualization[15495]
#define sipNameNr_meshFile 15504
#define sipName_meshFile &sipStrings_QtDataVisualization[15504]
#define sipNameNr_position 15513
#define sipName_position &sipStrings_QtDataVisualization[15513]
#define sipNameNr_reversed 15522
#define sipName_reversed &sipStrings_QtDataVisualization[15522]
#define sipNameNr_rotation 15531
#define sipName_rotation &sipStrings_QtDataVisualization[15531]
#define sipNameNr_rowCount 15540
#define sipName_rowCount &sipStrings_QtDataVisualization[15540]
#define sipNameNr_setAxisX 15549
#define sipName_setAxisX &sipStrings_QtDataVisualization[15549]
#define sipNameNr_setAxisY 15558
#define sipName_setAxisY &sipStrings_QtDataVisualization[15558]
#define sipNameNr_setAxisZ 15567
#define sipName_setAxisZ &sipStrings_QtDataVisualization[15567]
#define sipNameNr_setDirty 15576
#define sipName_setDirty &sipStrings_QtDataVisualization[15576]
#define sipNameNr_setItems 15585
#define sipName_setItems &sipStrings_QtDataVisualization[15585]
#define sipNameNr_setPolar 15594
#define sipName_setPolar &sipStrings_QtDataVisualization[15594]
#define sipNameNr_setRange 15603
#define sipName_setRange &sipStrings_QtDataVisualization[15603]
#define sipNameNr_setScene 15612
#define sipName_setScene &sipStrings_QtDataVisualization[15612]
#define sipNameNr_setTitle 15621
#define sipName_setTitle &sipStrings_QtDataVisualization[15621]
#define sipNameNr_setValue 15630
#define sipName_setValue &sipStrings_QtDataVisualization[15630]
#define sipNameNr_viewport 15639
#define sipName_viewport &sipStrings_QtDataVisualization[15639]
#define sipNameNr_xPosRole 15648
#define sipName_xPosRole &sipStrings_QtDataVisualization[15648]
#define sipNameNr_yPosRole 15657
#define sipName_yPosRole &sipStrings_QtDataVisualization[15657]
#define sipNameNr_zPosRole 15666
#define sipName_zPosRole &sipStrings_QtDataVisualization[15666]
#define sipNameNr_MMBLast 15675
#define sipName_MMBLast &sipStrings_QtDataVisualization[15675]
#define sipNameNr_MeshBar 15683
#define sipName_MeshBar &sipStrings_QtDataVisualization[15683]
#define sipNameNr_Q3DBars 3253
#define sipName_Q3DBars &sipStrings_QtDataVisualization[3253]
#define sipNameNr_ThemeQt 15691
#define sipName_ThemeQt &sipStrings_QtDataVisualization[15691]
#define sipNameNr___and__ 15699
#define sipName___and__ &sipStrings_QtDataVisualization[15699]
#define sipNameNr___int__ 15707
#define sipName___int__ &sipStrings_QtDataVisualization[15707]
#define sipNameNr___ior__ 15715
#define sipName___ior__ &sipStrings_QtDataVisualization[15715]
#define sipNameNr___xor__ 15723
#define sipName___xor__ &sipStrings_QtDataVisualization[15723]
#define sipNameNr_addAxis 15731
#define sipName_addAxis &sipStrings_QtDataVisualization[15731]
#define sipNameNr_addItem 15739
#define sipName_addItem &sipStrings_QtDataVisualization[15739]
#define sipNameNr_addRows 15747
#define sipName_addRows &sipStrings_QtDataVisualization[15747]
#define sipNameNr_isDirty 15755
#define sipName_isDirty &sipStrings_QtDataVisualization[15755]
#define sipNameNr_isPolar 15763
#define sipName_isPolar &sipStrings_QtDataVisualization[15763]
#define sipNameNr_rowAxis 15771
#define sipName_rowAxis &sipStrings_QtDataVisualization[15771]
#define sipNameNr_rowRole 15779
#define sipName_rowRole &sipStrings_QtDataVisualization[15779]
#define sipNameNr_scaling 15787
#define sipName_scaling &sipStrings_QtDataVisualization[15787]
#define sipNameNr_setBase 15795
#define sipName_setBase &sipStrings_QtDataVisualization[15795]
#define sipNameNr_setFont 15803
#define sipName_setFont &sipStrings_QtDataVisualization[15803]
#define sipNameNr_setItem 15811
#define sipName_setItem &sipStrings_QtDataVisualization[15811]
#define sipNameNr_setMesh 15819
#define sipName_setMesh &sipStrings_QtDataVisualization[15819]
#define sipNameNr_setName 15827
#define sipName_setName &sipStrings_QtDataVisualization[15827]
#define sipNameNr_setRows 15835
#define sipName_setRows &sipStrings_QtDataVisualization[15835]
#define sipNameNr_setText 15843
#define sipName_setText &sipStrings_QtDataVisualization[15843]
#define sipNameNr_setType 15851
#define sipName_setType &sipStrings_QtDataVisualization[15851]
#define sipNameNr_texture 15859
#define sipName_texture &sipStrings_QtDataVisualization[15859]
#define sipNameNr_valueAt 15867
#define sipName_valueAt &sipStrings_QtDataVisualization[15867]
#define sipNameNr___eq__ 15875
#define sipName___eq__ &sipStrings_QtDataVisualization[15875]
#define sipNameNr___ne__ 15882
#define sipName___ne__ &sipStrings_QtDataVisualization[15882]
#define sipNameNr___or__ 15889
#define sipName___or__ &sipStrings_QtDataVisualization[15889]
#define sipNameNr_addRow 15896
#define sipName_addRow &sipStrings_QtDataVisualization[15896]
#define sipNameNr_format 15903
#define sipName_format &sipStrings_QtDataVisualization[15903]
#define sipNameNr_itemAt 15910
#define sipName_itemAt &sipStrings_QtDataVisualization[15910]
#define sipNameNr_labels 15917
#define sipName_labels &sipStrings_QtDataVisualization[15917]
#define sipNameNr_locale 15924
#define sipName_locale &sipStrings_QtDataVisualization[15924]
#define sipNameNr_margin 15931
#define sipName_margin &sipStrings_QtDataVisualization[15931]
#define sipNameNr_parent 15938
#define sipName_parent &sipStrings_QtDataVisualization[15938]
#define sipNameNr_series 15945
#define sipName_series &sipStrings_QtDataVisualization[15945]
#define sipNameNr_setMax 15952
#define sipName_setMax &sipStrings_QtDataVisualization[15952]
#define sipNameNr_setMin 15959
#define sipName_setMin &sipStrings_QtDataVisualization[15959]
#define sipNameNr_setRow 15966
#define sipName_setRow &sipStrings_QtDataVisualization[15966]
#define sipNameNr_target 15973
#define sipName_target &sipStrings_QtDataVisualization[15973]
#define sipNameNr_themes 15980
#define sipName_themes &sipStrings_QtDataVisualization[15980]
#define sipNameNr_Theme 2320
#define sipName_Theme &sipStrings_QtDataVisualization[2320]
#define sipNameNr_array 15987
#define sipName_array &sipStrings_QtDataVisualization[15987]
#define sipNameNr_axisX 15993
#define sipName_axisX &sipStrings_QtDataVisualization[15993]
#define sipNameNr_axisY 15999
#define sipName_axisY &sipStrings_QtDataVisualization[15999]
#define sipNameNr_axisZ 16005
#define sipName_axisZ &sipStrings_QtDataVisualization[16005]
#define sipNameNr_event 16011
#define sipName_event &sipStrings_QtDataVisualization[16011]
#define sipNameNr_remap 16017
#define sipName_remap &sipStrings_QtDataVisualization[16017]
#define sipNameNr_rowAt 16023
#define sipName_rowAt &sipStrings_QtDataVisualization[16023]
#define sipNameNr_scene 16029
#define sipName_scene &sipStrings_QtDataVisualization[16029]
#define sipNameNr_title 16035
#define sipName_title &sipStrings_QtDataVisualization[16035]
#define sipNameNr_value 16041
#define sipName_value &sipStrings_QtDataVisualization[16041]
#define sipNameNr_Mesh 1521
#define sipName_Mesh &sipStrings_QtDataVisualization[1521]
#define sipNameNr_axes 16047
#define sipName_axes &sipStrings_QtDataVisualization[16047]
#define sipNameNr_axis 16052
#define sipName_axis &sipStrings_QtDataVisualization[16052]
#define sipNameNr_base 16057
#define sipName_base &sipStrings_QtDataVisualization[16057]
#define sipNameNr_font 16062
#define sipName_font &sipStrings_QtDataVisualization[16062]
#define sipNameNr_mesh 16067
#define sipName_mesh &sipStrings_QtDataVisualization[16067]
#define sipNameNr_name 16072
#define sipName_name &sipStrings_QtDataVisualization[16072]
#define sipNameNr_setX 16077
#define sipName_setX &sipStrings_QtDataVisualization[16077]
#define sipNameNr_setY 16082
#define sipName_setY &sipStrings_QtDataVisualization[16082]
#define sipNameNr_setZ 16087
#define sipName_setZ &sipStrings_QtDataVisualization[16087]
#define sipNameNr_size 16092
#define sipName_size &sipStrings_QtDataVisualization[16092]
#define sipNameNr_text 14822
#define sipName_text &sipStrings_QtDataVisualization[14822]
#define sipNameNr_type 16097
#define sipName_type &sipStrings_QtDataVisualization[16097]
#define sipNameNr_zoom 16102
#define sipName_zoom &sipStrings_QtDataVisualization[16102]
#define sipNameNr_max 16107
#define sipName_max &sipStrings_QtDataVisualization[16107]
#define sipNameNr_min 16111
#define sipName_min &sipStrings_QtDataVisualization[16111]
#define sipNameNr_x 4844
#define sipName_x &sipStrings_QtDataVisualization[4844]
#define sipNameNr_y 621
#define sipName_y &sipStrings_QtDataVisualization[621]
#define sipNameNr_z 16115
#define sipName_z &sipStrings_QtDataVisualization[16115]

#define sipMalloc                   sipAPI_QtDataVisualization->api_malloc
#define sipFree                     sipAPI_QtDataVisualization->api_free
#define sipBuildResult              sipAPI_QtDataVisualization->api_build_result
#define sipCallMethod               sipAPI_QtDataVisualization->api_call_method
#define sipCallProcedureMethod      sipAPI_QtDataVisualization->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtDataVisualization->api_call_error_handler
#define sipParseResultEx            sipAPI_QtDataVisualization->api_parse_result_ex
#define sipParseResult              sipAPI_QtDataVisualization->api_parse_result
#define sipParseArgs                sipAPI_QtDataVisualization->api_parse_args
#define sipParseKwdArgs             sipAPI_QtDataVisualization->api_parse_kwd_args
#define sipParsePair                sipAPI_QtDataVisualization->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtDataVisualization->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtDataVisualization->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtDataVisualization->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtDataVisualization->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtDataVisualization->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtDataVisualization->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtDataVisualization->api_add_exception
#define sipNoFunction               sipAPI_QtDataVisualization->api_no_function
#define sipNoMethod                 sipAPI_QtDataVisualization->api_no_method
#define sipAbstractMethod           sipAPI_QtDataVisualization->api_abstract_method
#define sipBadClass                 sipAPI_QtDataVisualization->api_bad_class
#define sipBadCatcherResult         sipAPI_QtDataVisualization->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtDataVisualization->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtDataVisualization->api_bad_operator_arg
#define sipTrace                    sipAPI_QtDataVisualization->api_trace
#define sipTransferBack             sipAPI_QtDataVisualization->api_transfer_back
#define sipTransferTo               sipAPI_QtDataVisualization->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtDataVisualization->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtDataVisualization->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtDataVisualization->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtDataVisualization->api_voidptr_type
#define sipGetPyObject              sipAPI_QtDataVisualization->api_get_pyobject
#define sipGetAddress               sipAPI_QtDataVisualization->api_get_address
#define sipGetMixinAddress          sipAPI_QtDataVisualization->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtDataVisualization->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtDataVisualization->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtDataVisualization->api_call_hook
#define sipEndThread                sipAPI_QtDataVisualization->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtDataVisualization->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtDataVisualization->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtDataVisualization->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtDataVisualization->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtDataVisualization->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtDataVisualization->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtDataVisualization->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtDataVisualization->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtDataVisualization->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtDataVisualization->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtDataVisualization->api_convert_to_bool
#define sipReleaseType              sipAPI_QtDataVisualization->api_release_type
#define sipConvertFromType          sipAPI_QtDataVisualization->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtDataVisualization->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtDataVisualization->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtDataVisualization->api_convert_from_enum
#define sipGetState                 sipAPI_QtDataVisualization->api_get_state
#define sipExportSymbol             sipAPI_QtDataVisualization->api_export_symbol
#define sipImportSymbol             sipAPI_QtDataVisualization->api_import_symbol
#define sipFindType                 sipAPI_QtDataVisualization->api_find_type
#define sipBytes_AsChar             sipAPI_QtDataVisualization->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtDataVisualization->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtDataVisualization->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtDataVisualization->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtDataVisualization->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtDataVisualization->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtDataVisualization->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtDataVisualization->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtDataVisualization->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtDataVisualization->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtDataVisualization->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtDataVisualization->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtDataVisualization->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtDataVisualization->api_get_reference
#define sipKeepReference            sipAPI_QtDataVisualization->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtDataVisualization->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtDataVisualization->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtDataVisualization->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtDataVisualization->api_type_scope
#define sipResolveTypedef           sipAPI_QtDataVisualization->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtDataVisualization->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtDataVisualization->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtDataVisualization->api_init_mixin
#define sipExportModule             sipAPI_QtDataVisualization->api_export_module
#define sipInitModule               sipAPI_QtDataVisualization->api_init_module
#define sipGetInterpreter           sipAPI_QtDataVisualization->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtDataVisualization->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtDataVisualization->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtDataVisualization->api_py_type_dict
#define sipPyTypeName               sipAPI_QtDataVisualization->api_py_type_name
#define sipGetCFunction             sipAPI_QtDataVisualization->api_get_c_function
#define sipGetMethod                sipAPI_QtDataVisualization->api_get_method
#define sipFromMethod               sipAPI_QtDataVisualization->api_from_method
#define sipGetDate                  sipAPI_QtDataVisualization->api_get_date
#define sipFromDate                 sipAPI_QtDataVisualization->api_from_date
#define sipGetDateTime              sipAPI_QtDataVisualization->api_get_datetime
#define sipFromDateTime             sipAPI_QtDataVisualization->api_from_datetime
#define sipGetTime                  sipAPI_QtDataVisualization->api_get_time
#define sipFromTime                 sipAPI_QtDataVisualization->api_from_time
#define sipIsUserType               sipAPI_QtDataVisualization->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtDataVisualization->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtDataVisualization->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtDataVisualization->api_unicode_write
#define sipUnicodeData              sipAPI_QtDataVisualization->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtDataVisualization->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtDataVisualization->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtDataVisualization->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtDataVisualization->api_is_derived_class
#define sipGetUserObject            sipAPI_QtDataVisualization->api_get_user_object
#define sipSetUserObject            sipAPI_QtDataVisualization->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtDataVisualization->api_register_event_handler
#define sipConvertToArray           sipAPI_QtDataVisualization->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtDataVisualization->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtDataVisualization->api_enable_gc
#define sipPrintObject              sipAPI_QtDataVisualization->api_print_object
#define sipLong_AsChar              sipAPI_QtDataVisualization->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtDataVisualization->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtDataVisualization->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtDataVisualization->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtDataVisualization->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtDataVisualization->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtDataVisualization->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtDataVisualization->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtDataVisualization->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtDataVisualization->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtDataVisualization->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtDataVisualization->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtDataVisualization->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtDataVisualization->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtDataVisualization->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtDataVisualization->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtDataVisualization->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtDataVisualization->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtDataVisualization->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtDataVisualization->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtDataVisualization->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtDataVisualization->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtDataVisualization->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtDataVisualization->api_connect_rx
#define sipConvertRx                sipAPI_QtDataVisualization->api_convert_rx
#define sipDisconnectRx             sipAPI_QtDataVisualization->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtDataVisualization->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtDataVisualization->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtDataVisualization->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtDataVisualization->api_same_slot
#define sipSaveSlot                 sipAPI_QtDataVisualization->api_save_slot
#define sipVisitSlot                sipAPI_QtDataVisualization->api_visit_slot
#define sipIsPyMethod               sipAPI_QtDataVisualization->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtDataVisualization[];


#define sipType_QtDataVisualization_QAbstract3DGraph sipExportedTypes_QtDataVisualization[32]

#define sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHint sipExportedTypes_QtDataVisualization[34]

#define sipType_QtDataVisualization_QAbstract3DGraph_ElementType sipExportedTypes_QtDataVisualization[33]

#define sipType_QtDataVisualization_QAbstract3DGraph_ShadowQuality sipExportedTypes_QtDataVisualization[38]

#define sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlag sipExportedTypes_QtDataVisualization[36]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DGraph;

#define sipType_QtDataVisualization_Q3DBars sipExportedTypes_QtDataVisualization[17]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DBars;

#define sipType_QtDataVisualization_Q3DObject sipExportedTypes_QtDataVisualization[22]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DObject;

#define sipType_QtDataVisualization_Q3DCamera sipExportedTypes_QtDataVisualization[18]

#define sipType_QtDataVisualization_Q3DCamera_CameraPreset sipExportedTypes_QtDataVisualization[19]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DCamera;

#define sipType_QtDataVisualization_QAbstract3DInputHandler sipExportedTypes_QtDataVisualization[39]

#define sipType_QtDataVisualization_QAbstract3DInputHandler_InputView sipExportedTypes_QtDataVisualization[40]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DInputHandler;

#define sipType_QtDataVisualization_Q3DInputHandler sipExportedTypes_QtDataVisualization[20]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DInputHandler;

#define sipType_QtDataVisualization_Q3DLight sipExportedTypes_QtDataVisualization[21]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DLight;

#define sipType_QtDataVisualization_Q3DScatter sipExportedTypes_QtDataVisualization[23]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DScatter;

#define sipType_QtDataVisualization_Q3DScene sipExportedTypes_QtDataVisualization[24]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DScene;

#define sipType_QtDataVisualization_Q3DSurface sipExportedTypes_QtDataVisualization[25]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DSurface;

#define sipType_QtDataVisualization_Q3DTheme sipExportedTypes_QtDataVisualization[26]

#define sipType_QtDataVisualization_Q3DTheme_Theme sipExportedTypes_QtDataVisualization[28]

#define sipType_QtDataVisualization_Q3DTheme_ColorStyle sipExportedTypes_QtDataVisualization[27]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DTheme;

#define sipType_QtDataVisualization_QAbstract3DAxis sipExportedTypes_QtDataVisualization[29]

#define sipType_QtDataVisualization_QAbstract3DAxis_AxisType sipExportedTypes_QtDataVisualization[31]

#define sipType_QtDataVisualization_QAbstract3DAxis_AxisOrientation sipExportedTypes_QtDataVisualization[30]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DAxis;

#define sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlags sipExportedTypes_QtDataVisualization[37]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DGraph_SelectionFlags;

#define sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHints sipExportedTypes_QtDataVisualization[35]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DGraph_OptimizationHints;

#define sipType_QtDataVisualization_QAbstract3DSeries sipExportedTypes_QtDataVisualization[41]

#define sipType_QtDataVisualization_QAbstract3DSeries_Mesh sipExportedTypes_QtDataVisualization[42]

#define sipType_QtDataVisualization_QAbstract3DSeries_SeriesType sipExportedTypes_QtDataVisualization[43]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DSeries;

#define sipType_QtDataVisualization_QAbstractDataProxy sipExportedTypes_QtDataVisualization[44]

#define sipType_QtDataVisualization_QAbstractDataProxy_DataType sipExportedTypes_QtDataVisualization[45]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstractDataProxy;

#define sipType_QtDataVisualization_QBar3DSeries sipExportedTypes_QtDataVisualization[46]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QBar3DSeries;

#define sipType_QtDataVisualization_QBarDataItem sipExportedTypes_QtDataVisualization[47]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QBarDataItem;

#define sipType_QtDataVisualization_QBarDataProxy sipExportedTypes_QtDataVisualization[48]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QBarDataProxy;

#define sipType_QtDataVisualization_QCategory3DAxis sipExportedTypes_QtDataVisualization[49]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QCategory3DAxis;

#define sipType_QtDataVisualization_QCustom3DItem sipExportedTypes_QtDataVisualization[50]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DItem;

#define sipType_QtDataVisualization_QCustom3DLabel sipExportedTypes_QtDataVisualization[51]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DLabel;

#define sipType_QtDataVisualization_QCustom3DVolume sipExportedTypes_QtDataVisualization[52]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DVolume;

#define sipType_QtDataVisualization_QSurfaceDataProxy sipExportedTypes_QtDataVisualization[67]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QSurfaceDataProxy;

#define sipType_QtDataVisualization_QHeightMapSurfaceDataProxy sipExportedTypes_QtDataVisualization[53]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QHeightMapSurfaceDataProxy;

#define sipType_QtDataVisualization_QItemModelBarDataProxy sipExportedTypes_QtDataVisualization[54]

#define sipType_QtDataVisualization_QItemModelBarDataProxy_MultiMatchBehavior sipExportedTypes_QtDataVisualization[55]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelBarDataProxy;

#define sipType_QtDataVisualization_QScatterDataProxy sipExportedTypes_QtDataVisualization[62]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QScatterDataProxy;

#define sipType_QtDataVisualization_QItemModelScatterDataProxy sipExportedTypes_QtDataVisualization[56]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelScatterDataProxy;

#define sipType_QtDataVisualization_QItemModelSurfaceDataProxy sipExportedTypes_QtDataVisualization[57]

#define sipType_QtDataVisualization_QItemModelSurfaceDataProxy_MultiMatchBehavior sipExportedTypes_QtDataVisualization[58]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelSurfaceDataProxy;

#define sipType_QtDataVisualization_QValue3DAxisFormatter sipExportedTypes_QtDataVisualization[70]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QValue3DAxisFormatter;

#define sipType_QtDataVisualization_QLogValue3DAxisFormatter sipExportedTypes_QtDataVisualization[59]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QLogValue3DAxisFormatter;

#define sipType_QtDataVisualization_QScatter3DSeries sipExportedTypes_QtDataVisualization[60]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QScatter3DSeries;

#define sipType_QtDataVisualization_QScatterDataItem sipExportedTypes_QtDataVisualization[61]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QScatterDataItem;

#define sipType_QtDataVisualization_QSurface3DSeries sipExportedTypes_QtDataVisualization[63]

#define sipType_QtDataVisualization_QSurface3DSeries_DrawFlag sipExportedTypes_QtDataVisualization[64]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QSurface3DSeries;

#define sipType_QtDataVisualization_QSurface3DSeries_DrawFlags sipExportedTypes_QtDataVisualization[65]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlags;

#define sipType_QtDataVisualization_QSurfaceDataItem sipExportedTypes_QtDataVisualization[66]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QSurfaceDataItem;

#define sipType_QtDataVisualization_QTouch3DInputHandler sipExportedTypes_QtDataVisualization[68]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QTouch3DInputHandler;

#define sipType_QtDataVisualization_QValue3DAxis sipExportedTypes_QtDataVisualization[69]

extern sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QValue3DAxis;

#define sipType_QList_0100QLinearGradient sipExportedTypes_QtDataVisualization[1]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0100QLinearGradient;

#define sipType_QList_0100QColor sipExportedTypes_QtDataVisualization[0]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0100QColor;

#define sipType_QList_0101QtDataVisualization_QSurface3DSeries sipExportedTypes_QtDataVisualization[10]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QSurface3DSeries;

#define sipType_QList_0101QtDataVisualization_QValue3DAxis sipExportedTypes_QtDataVisualization[11]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QValue3DAxis;

#define sipType_QList_0101QtDataVisualization_QScatter3DSeries sipExportedTypes_QtDataVisualization[9]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QScatter3DSeries;

#define sipType_QList_0101QtDataVisualization_QAbstract3DAxis sipExportedTypes_QtDataVisualization[5]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QAbstract3DAxis;

#define sipType_QList_0101QtDataVisualization_QBar3DSeries sipExportedTypes_QtDataVisualization[7]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QBar3DSeries;

#define sipType_QList_0101QtDataVisualization_QCustom3DItem sipExportedTypes_QtDataVisualization[8]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QCustom3DItem;

#define sipType_QList_0101QtDataVisualization_Q3DTheme sipExportedTypes_QtDataVisualization[4]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_Q3DTheme;

#define sipType_QList_0101QtDataVisualization_QAbstract3DInputHandler sipExportedTypes_QtDataVisualization[6]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QAbstract3DInputHandler;

#define sipType_QVector_0100QtDataVisualization_QSurfaceDataItem sipExportedTypes_QtDataVisualization[15]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QVector_0100QtDataVisualization_QSurfaceDataItem;

#define sipType_QList_0601QVector_0100QtDataVisualization_QSurfaceDataItem sipExportedTypes_QtDataVisualization[3]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0601QVector_0100QtDataVisualization_QSurfaceDataItem;

#define sipType_QVector_0100QtDataVisualization_QScatterDataItem sipExportedTypes_QtDataVisualization[14]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QVector_0100QtDataVisualization_QScatterDataItem;

#define sipType_QVector_0100QtDataVisualization_QBarDataItem sipExportedTypes_QtDataVisualization[13]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QVector_0100QtDataVisualization_QBarDataItem;

#define sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem sipExportedTypes_QtDataVisualization[2]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_0601QVector_0100QtDataVisualization_QBarDataItem;

#define sipType_QVector_1300 sipExportedTypes_QtDataVisualization[16]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QVector_1300;

#define sipType_QVector_0101QImage sipExportedTypes_QtDataVisualization[12]

extern sipMappedTypeDef sipTypeDef_QtDataVisualization_QVector_0101QImage;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtDataVisualization;
extern sipExportedModuleDef sipModuleAPI_QtDataVisualization;
extern sipTypeDef *sipExportedTypes_QtDataVisualization[];

#define sipType_Qt_Axis sipImportedTypes_QtDataVisualization_QtCore[14].it_td

#define sipType_QObject sipImportedTypes_QtDataVisualization_QtCore[5].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtDataVisualization_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtDataVisualization_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtDataVisualization_QtCore[13].it_td

#define sipType_QChildEvent sipImportedTypes_QtDataVisualization_QtCore[1].it_td

#define sipType_QLocale sipImportedTypes_QtDataVisualization_QtCore[3].it_td

#define sipType_QMetaMethod sipImportedTypes_QtDataVisualization_QtCore[4].it_td

#define sipType_QPoint sipImportedTypes_QtDataVisualization_QtCore[6].it_td

#define sipType_QRect sipImportedTypes_QtDataVisualization_QtCore[7].it_td

#define sipType_QRegExp sipImportedTypes_QtDataVisualization_QtCore[8].it_td

#define sipType_QSize sipImportedTypes_QtDataVisualization_QtCore[9].it_td

#define sipType_QSizeF sipImportedTypes_QtDataVisualization_QtCore[10].it_td

#define sipType_QStringList sipImportedTypes_QtDataVisualization_QtCore[12].it_td

#define sipType_QString sipImportedTypes_QtDataVisualization_QtCore[11].it_td
extern sipImportedTypeDef sipImportedTypes_QtDataVisualization_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[];

#define sipType_QColor sipImportedTypes_QtDataVisualization_QtGui[0].it_td

#define sipType_QLinearGradient sipImportedTypes_QtDataVisualization_QtGui[8].it_td

#define sipType_QMouseEvent sipImportedTypes_QtDataVisualization_QtGui[9].it_td

#define sipType_QWheelEvent sipImportedTypes_QtDataVisualization_QtGui[22].it_td

#define sipType_QTabletEvent sipImportedTypes_QtDataVisualization_QtGui[17].it_td

#define sipType_QKeyEvent sipImportedTypes_QtDataVisualization_QtGui[7].it_td

#define sipType_QFocusEvent sipImportedTypes_QtDataVisualization_QtGui[2].it_td

#define sipType_QMoveEvent sipImportedTypes_QtDataVisualization_QtGui[10].it_td

#define sipType_QResizeEvent sipImportedTypes_QtDataVisualization_QtGui[12].it_td

#define sipType_QShowEvent sipImportedTypes_QtDataVisualization_QtGui[13].it_td

#define sipType_QHideEvent sipImportedTypes_QtDataVisualization_QtGui[4].it_td

#define sipType_QTouchEvent sipImportedTypes_QtDataVisualization_QtGui[18].it_td

#define sipType_QExposeEvent sipImportedTypes_QtDataVisualization_QtGui[1].it_td

#define sipType_QFont sipImportedTypes_QtDataVisualization_QtGui[3].it_td

#define sipType_QImage sipImportedTypes_QtDataVisualization_QtGui[5].it_td

#define sipType_QImage_Format sipImportedTypes_QtDataVisualization_QtGui[6].it_td

#define sipType_QSurface sipImportedTypes_QtDataVisualization_QtGui[14].it_td

#define sipType_QSurface_SurfaceType sipImportedTypes_QtDataVisualization_QtGui[15].it_td

#define sipType_QWindow sipImportedTypes_QtDataVisualization_QtGui[23].it_td

#define sipType_QQuaternion sipImportedTypes_QtDataVisualization_QtGui[11].it_td

#define sipType_QSurfaceFormat sipImportedTypes_QtDataVisualization_QtGui[16].it_td

#define sipType_QVector3D sipImportedTypes_QtDataVisualization_QtGui[19].it_td

#define sipType_QVector_2200 sipImportedTypes_QtDataVisualization_QtGui[20].it_td

#define sipType_QVector_1900 sipImportedTypes_QtDataVisualization_QtGui[21].it_td
extern sipImportedTypeDef sipImportedTypes_QtDataVisualization_QtGui[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtDataVisualization_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtDataVisualization_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtDataVisualization_qt_metacast;

#endif
